@@ -1,3 +1,4 @@
+//go:build integration
 // +build integration
 
 // To enable compilation of this file in Goland, go to "Settings -> Go -> Vendoring & Build Tags -> Custom Tags" and add "integration"
@@ -26,21 +27,21 @@ import (
 	"bytes"
 	"context"
 	"encoding/json"
-	"errors"
 	"fmt"
 	"io"
 	"io/ioutil"
 	"os"
 	"os/exec"
+	"reflect"
 	"strings"
 	"testing"
 	"time"
 
-	"github.com/apache/camel-k/pkg/util/patch"
+	"github.com/apache/camel-k/pkg/platform"
 	"github.com/google/uuid"
 	"github.com/onsi/gomega"
+	"github.com/pkg/errors"
 	"github.com/spf13/cobra"
-	"k8s.io/apimachinery/pkg/types"
 
 	appsv1 "k8s.io/api/apps/v1"
 	"k8s.io/api/batch/v1beta1"
@@ -49,6 +50,8 @@ import (
 	rbacv1 "k8s.io/api/rbac/v1"
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/labels"
+	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/utils/pointer"
 
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
@@ -71,6 +74,7 @@ import (
 	"github.com/apache/camel-k/pkg/util/kubernetes"
 	"github.com/apache/camel-k/pkg/util/log"
 	"github.com/apache/camel-k/pkg/util/openshift"
+	"github.com/apache/camel-k/pkg/util/patch"
 
 	// let's enable addons in all tests
 	_ "github.com/apache/camel-k/addons"
@@ -226,6 +230,33 @@ func KamelWithContext(ctx context.Context, args ...string) *cobra.Command {
 	return c
 }
 
+func Make(rule string, args ...string) *exec.Cmd {
+	return MakeWithContext(TestContext, rule, args...)
+}
+
+func MakeWithContext(ctx context.Context, rule string, args ...string) *exec.Cmd {
+	makeArgs := os.Getenv("MAKE_ARGS")
+	defaultArgs := strings.Fields(makeArgs)
+	args = append(defaultArgs, args...)
+
+	makeDir := os.Getenv("MAKE_DIR")
+	if makeDir == "" {
+		makeDir = "../../../install"
+	} else {
+		fmt.Printf("Using alternative make directory on path %s\n", makeDir)
+	}
+
+	if fi, e := os.Stat(makeDir); e != nil && os.IsNotExist(e) {
+		panic(e)
+	} else if !fi.Mode().IsDir() {
+		panic(e)
+	}
+
+	args = append([]string{"-C", makeDir, rule}, args...)
+
+	return exec.Command("make", args...)
+}
+
 /*
 	Curryied utility functions for testing
 */
@@ -339,6 +370,16 @@ func IntegrationPod(ns string, name string) func() *corev1.Pod {
 	}
 }
 
+func IntegrationPodHas(ns string, name string, predicate func(pod *corev1.Pod) bool) func() bool {
+	return func() bool {
+		pod := IntegrationPod(ns, name)()
+		if pod == nil {
+			return false
+		}
+		return predicate(pod)
+	}
+}
+
 func IntegrationPods(ns string, name string) func() []corev1.Pod {
 	return func() []corev1.Pod {
 		lst := corev1.PodList{
@@ -393,6 +434,18 @@ func IntegrationCondition(ns string, name string, conditionType v1.IntegrationCo
 	}
 }
 
+func AssignIntegrationToOperator(ns, name, operator string) error {
+	it := Integration(ns, name)()
+	if it == nil {
+		return fmt.Errorf("cannot assign integration %q to operator: integration not found", name)
+	}
+	if it.Annotations == nil {
+		it.Annotations = make(map[string]string)
+	}
+	it.Annotations[v1.OperatorIDAnnotation] = operator
+	return TestClient().Update(TestContext, it)
+}
+
 func Lease(ns string, name string) func() *coordination.Lease {
 	return func() *coordination.Lease {
 		lease := coordination.Lease{}
@@ -479,6 +532,16 @@ func Route(ns string, name string) func() *routev1.Route {
 	}
 }
 
+func RouteStatus(ns string, name string) func() string {
+	return func() string {
+		route := Route(ns, name)()
+		if route == nil || len(route.Status.Ingress) == 0 {
+			return ""
+		}
+		return string(route.Status.Ingress[0].Conditions[0].Status)
+	}
+}
+
 func IntegrationCronJob(ns string, name string) func() *v1beta1.CronJob {
 	return func() *v1beta1.CronJob {
 		lst := v1beta1.CronJobList{
@@ -571,17 +634,56 @@ func IntegrationKit(ns string, name string) func() string {
 	}
 }
 
-func UpdateIntegration(ns string, name string, upd func(it *v1.Integration)) error {
+func Kit(ns, name string) func() *v1.IntegrationKit {
+	return func() *v1.IntegrationKit {
+		kit := v1.NewIntegrationKit(ns, name)
+		if err := TestClient().Get(TestContext, ctrl.ObjectKeyFromObject(kit), kit); err != nil && !k8serrors.IsNotFound(err) {
+			panic(err)
+		} else if err != nil && k8serrors.IsNotFound(err) {
+			return nil
+		}
+		return kit
+	}
+}
+
+func KitPhase(ns, name string) func() v1.IntegrationKitPhase {
+	return func() v1.IntegrationKitPhase {
+		kit := Kit(ns, name)()
+		if kit == nil {
+			return v1.IntegrationKitPhaseNone
+		}
+		return kit.Status.Phase
+	}
+}
+
+func UpdateIntegration(ns string, name string, mutate func(it *v1.Integration)) error {
 	it := Integration(ns, name)()
 	if it == nil {
 		return fmt.Errorf("no integration named %s found", name)
 	}
-	upd(it)
-	return TestClient().Update(TestContext, it)
+	target := it.DeepCopy()
+	mutate(target)
+	return TestClient().Update(TestContext, target)
+}
+
+func PatchIntegration(ns string, name string, mutate func(it *v1.Integration)) error {
+	it := Integration(ns, name)()
+	if it == nil {
+		return fmt.Errorf("no integration named %s found", name)
+	}
+	target := it.DeepCopy()
+	mutate(target)
+	p, err := patch.PositiveMergePatch(it, target)
+	if err != nil {
+		return err
+	} else if len(p) == 0 {
+		return nil
+	}
+	return TestClient().Patch(TestContext, target, ctrl.RawPatch(types.MergePatchType, p))
 }
 
 func ScaleIntegration(ns string, name string, replicas int32) error {
-	return UpdateIntegration(ns, name, func(it *v1.Integration) {
+	return PatchIntegration(ns, name, func(it *v1.Integration) {
 		it.Spec.Replicas = &replicas
 	})
 }
@@ -659,26 +761,77 @@ func ScaleKameletBinding(ns string, name string, replicas int32) error {
 	})
 }
 
-func Kits(ns string, filters ...func(*v1.IntegrationKit) bool) func() []v1.IntegrationKit {
+func AssignKameletBindingToOperator(ns, name, operator string) error {
+	klb := KameletBinding(ns, name)()
+	if klb == nil {
+		return fmt.Errorf("cannot assign kamelet binding %q to operator: kamelet binding not found", name)
+	}
+	if klb.Annotations == nil {
+		klb.Annotations = make(map[string]string)
+	}
+	klb.Annotations[v1.OperatorIDAnnotation] = operator
+	return TestClient().Update(TestContext, klb)
+}
+
+type KitFilter interface {
+	Match(*v1.IntegrationKit) bool
+}
+
+func KitWithPhase(phase v1.IntegrationKitPhase) KitFilter {
+	return &kitFilter{
+		filter: func(kit *v1.IntegrationKit) bool {
+			return kit.Status.Phase == phase
+		},
+	}
+}
+
+func KitWithVersion(version string) KitFilter {
+	return &kitFilter{
+		filter: func(kit *v1.IntegrationKit) bool {
+			return kit.Status.Version == version
+		},
+	}
+}
+
+func KitWithLabels(kitLabels map[string]string) ctrl.ListOption {
+	return ctrl.MatchingLabelsSelector{
+		Selector: labels.Set(kitLabels).AsSelector(),
+	}
+}
+
+type kitFilter struct {
+	filter func(*v1.IntegrationKit) bool
+}
+
+func (f *kitFilter) Match(kit *v1.IntegrationKit) bool {
+	return f.filter(kit)
+}
+
+func Kits(ns string, options ...interface{}) func() []v1.IntegrationKit {
+	filters := make([]KitFilter, 0)
+	listOptions := []ctrl.ListOption{ctrl.InNamespace(ns)}
+	for _, option := range options {
+		switch o := option.(type) {
+		case KitFilter:
+			filters = append(filters, o)
+		case ctrl.ListOption:
+			listOptions = append(listOptions, o)
+		default:
+			panic(fmt.Errorf("unsupported kits option %q", o))
+		}
+	}
+
 	return func() []v1.IntegrationKit {
 		list := v1.NewIntegrationKitList()
-		if err := TestClient().List(TestContext, &list, ctrl.InNamespace(ns)); err != nil {
+		if err := TestClient().List(TestContext, &list, listOptions...); err != nil {
 			panic(err)
 		}
 
-		if len(filters) == 0 {
-			filters = []func(*v1.IntegrationKit) bool{
-				func(kit *v1.IntegrationKit) bool {
-					return true
-				},
-			}
-		}
-
 		var kits []v1.IntegrationKit
 	kits:
 		for _, kit := range list.Items {
 			for _, filter := range filters {
-				if !filter(&kit) {
+				if !filter.Match(&kit) {
 					continue kits
 				}
 			}
@@ -853,20 +1006,26 @@ func DeploymentCondition(ns string, name string, conditionType appsv1.Deployment
 	}
 }
 
-func Build(ns string, name string) func() *v1.Build {
+func Build(ns, name string) func() *v1.Build {
 	return func() *v1.Build {
 		build := v1.NewBuild(ns, name)
-		key := ctrl.ObjectKey{
-			Namespace: ns,
-			Name:      name,
-		}
-		if err := TestClient().Get(TestContext, key, &build); err != nil && k8serrors.IsNotFound(err) {
+		if err := TestClient().Get(TestContext, ctrl.ObjectKeyFromObject(build), build); err != nil && k8serrors.IsNotFound(err) {
 			return nil
 		} else if err != nil {
 			log.Error(err, "Error while retrieving build "+name)
 			return nil
 		}
-		return &build
+		return build
+	}
+}
+
+func BuildPhase(ns, name string) func() v1.BuildPhase {
+	return func() v1.BuildPhase {
+		build := Build(ns, name)()
+		if build != nil {
+			return build.Status.Phase
+		}
+		return v1.BuildPhaseNone
 	}
 }
 
@@ -880,7 +1039,21 @@ func Platform(ns string) func() *v1.IntegrationPlatform {
 			return nil
 		}
 		if len(lst.Items) > 1 {
-			panic("multiple integration platforms found in namespace " + ns)
+			var pl *v1.IntegrationPlatform
+			for _, p := range lst.Items {
+				p := p
+				if platform.IsSecondary(&p) {
+					continue
+				}
+				if pl != nil {
+					panic("multiple primary integration platforms found in namespace " + ns)
+				}
+				pl = &p
+			}
+			if pl == nil {
+				panic(fmt.Sprintf("multiple integration platforms found in namespace %q but no one is primary", ns))
+			}
+			return pl
 		}
 		return &lst.Items[0]
 	}
@@ -900,17 +1073,6 @@ func DeletePlatform(ns string) func() bool {
 	}
 }
 
-func SetPlatformVersion(ns string, version string) func() error {
-	return func() error {
-		p := Platform(ns)()
-		if p == nil {
-			return errors.New("no platform found")
-		}
-		p.Status.Version = version
-		return TestClient().Status().Update(TestContext, p)
-	}
-}
-
 func PlatformVersion(ns string) func() string {
 	return func() string {
 		p := Platform(ns)()
@@ -941,6 +1103,74 @@ func PlatformProfile(ns string) func() v1.TraitProfile {
 	}
 }
 
+func AssignPlatformToOperator(ns, operator string) error {
+	pl := Platform(ns)()
+	if pl == nil {
+		return errors.New("cannot assign platform to operator: no platform found")
+	}
+	if pl.Annotations == nil {
+		pl.Annotations = make(map[string]string)
+	}
+	pl.Annotations[v1.OperatorIDAnnotation] = operator
+	return TestClient().Update(TestContext, pl)
+}
+
+func ConfigureSecondayPlatfromWith(ns string, customizer func(pl *v1.IntegrationPlatform)) error {
+	pl := Platform(ns)()
+	if pl == nil {
+		return errors.New("cannot find primary platform")
+	}
+	if pl.Annotations == nil {
+		pl.Annotations = make(map[string]string)
+	}
+	pl.Annotations[v1.SecondaryPlatformAnnotation] = "true"
+	pl.ObjectMeta.ResourceVersion = ""
+	pl.Name = ""
+	pl.Status = v1.IntegrationPlatformStatus{}
+	customizer(pl)
+	return TestClient().Create(TestContext, pl)
+}
+
+func CRDs() func() []metav1.APIResource {
+	return func() []metav1.APIResource {
+
+		kinds := []string{
+			reflect.TypeOf(v1.Build{}).Name(),
+			reflect.TypeOf(v1.Integration{}).Name(),
+			reflect.TypeOf(v1.IntegrationKit{}).Name(),
+			reflect.TypeOf(v1.IntegrationPlatform{}).Name(),
+			reflect.TypeOf(v1alpha1.Kamelet{}).Name(),
+			reflect.TypeOf(v1alpha1.KameletBinding{}).Name(),
+		}
+
+		versions := []string{"v1", "v1alpha1"}
+		present := []metav1.APIResource{}
+
+		for _, version := range versions {
+			lst, err := TestClient().Discovery().ServerResourcesForGroupVersion("camel.apache.org/" + version)
+			if err != nil && k8serrors.IsNotFound(err) {
+				return nil
+			} else if err != nil {
+				panic(err)
+			}
+
+			for _, res := range lst.APIResources {
+				if strings.Contains(res.Name, "/") {
+					continue // ignore sub types like status
+				}
+
+				for _, k := range kinds {
+					if k == res.Kind {
+						present = append(present, res)
+					}
+				}
+			}
+		}
+
+		return present
+	}
+}
+
 func OperatorPod(ns string) func() *corev1.Pod {
 	return func() *corev1.Pod {
 		lst := corev1.PodList{
@@ -964,8 +1194,57 @@ func OperatorPod(ns string) func() *corev1.Pod {
 	}
 }
 
-func Role(ns string) func() *rbacv1.Role {
-	return func() *rbacv1.Role {
+func OperatorTryPodForceKill(ns string, timeSeconds int) {
+	pod := OperatorPod(ns)()
+	if pod != nil {
+		if err := TestClient().Delete(TestContext, pod, ctrl.GracePeriodSeconds(timeSeconds)); err != nil {
+			log.Error(err, "cannot forcefully kill the pod")
+		}
+	}
+}
+
+func ScaleOperator(ns string, replicas int32) error {
+	operator, err := TestClient().AppsV1().Deployments(ns).Get(TestContext, "camel-k-operator", metav1.GetOptions{})
+	if err != nil {
+		return err
+	}
+	operator.Spec.Replicas = &replicas
+	_, err = TestClient().AppsV1().Deployments(ns).Update(TestContext, operator, metav1.UpdateOptions{})
+	if err != nil {
+		return err
+	}
+
+	if replicas == 0 {
+		// speedup scale down by killing the pod
+		OperatorTryPodForceKill(ns, 10)
+	}
+	return nil
+}
+
+func ClusterRole() func() []rbacv1.ClusterRole {
+	return func() []rbacv1.ClusterRole {
+		lst := rbacv1.ClusterRoleList{
+			TypeMeta: metav1.TypeMeta{
+				Kind:       "ClusterRole",
+				APIVersion: rbacv1.SchemeGroupVersion.String(),
+			},
+		}
+		err := TestClient().List(TestContext, &lst,
+			ctrl.MatchingLabels{
+				"app": "camel-k",
+			})
+		if err != nil {
+			panic(err)
+		}
+		if len(lst.Items) == 0 {
+			return nil
+		}
+		return lst.Items
+	}
+}
+
+func Role(ns string) func() []rbacv1.Role {
+	return func() []rbacv1.Role {
 		lst := rbacv1.RoleList{
 			TypeMeta: metav1.TypeMeta{
 				Kind:       "Role",
@@ -983,7 +1262,7 @@ func Role(ns string) func() *rbacv1.Role {
 		if len(lst.Items) == 0 {
 			return nil
 		}
-		return &lst.Items[0]
+		return lst.Items
 	}
 }
 
@@ -1060,10 +1339,23 @@ func Kamelet(name string, ns string) func() *v1alpha1.Kamelet {
 	}
 }
 
+func KameletHasLabel(name string, ns string, label string) func() bool {
+	return func() bool {
+		k := Kamelet(name, ns)()
+		if k == nil {
+			return false
+		}
+		if _, ok := k.Labels[label]; ok {
+			return true
+		}
+		return false
+	}
+}
+
 func ClusterDomainName() (string, error) {
 	dns := configv1.DNS{}
 	key := ctrl.ObjectKey{
-		Name:      "cluster",
+		Name: "cluster",
 	}
 	err := TestClient().Get(TestContext, key, &dns)
 	if err != nil {
@@ -1072,7 +1364,6 @@ func ClusterDomainName() (string, error) {
 	return dns.Spec.BaseDomain, nil
 }
 
-
 /*
 	Tekton
 */
@@ -1092,12 +1383,12 @@ func CreateOperatorRole(ns string) (err error) {
 		// This should ideally be removed from the common RBAC manifest.
 		customizer = install.RemoveIngressRoleCustomizer
 	}
-	err = install.Resource(TestContext, TestClient(), ns, true, customizer, "/rbac/operator-role-kubernetes.yaml")
+	err = install.Resource(TestContext, TestClient(), ns, true, customizer, "/rbac/operator-role.yaml")
 	if err != nil {
 		return err
 	}
 	if oc {
-		return install.Resource(TestContext, TestClient(), ns, true, install.IdentityResourceCustomizer, "/rbac/operator-role-openshift.yaml")
+		return install.Resource(TestContext, TestClient(), ns, true, install.IdentityResourceCustomizer, "/rbac/openshift/operator-role-openshift.yaml")
 	}
 	return nil
 }
@@ -1112,7 +1403,7 @@ func CreateOperatorRoleBinding(ns string) error {
 		return err
 	}
 	if oc {
-		return install.Resource(TestContext, TestClient(), ns, true, install.IdentityResourceCustomizer, "/rbac/operator-role-binding-openshift.yaml")
+		return install.Resource(TestContext, TestClient(), ns, true, install.IdentityResourceCustomizer, "/rbac/openshift/operator-role-binding-openshift.yaml")
 	}
 	return nil
 }
@@ -1170,63 +1461,70 @@ func CreateKnativeChannel(ns string, name string) func() error {
 	Kamelets
 */
 
-func CreateTimerKamelet(ns string, name string) func() error {
+func CreateKamelet(ns string, name string, flow map[string]interface{}, properties map[string]v1alpha1.JSONSchemaProp, labels map[string]string) func() error {
 	return func() error {
 		kamelet := v1alpha1.Kamelet{
 			ObjectMeta: metav1.ObjectMeta{
 				Namespace: ns,
 				Name:      name,
+				Labels:    labels,
 			},
 			Spec: v1alpha1.KameletSpec{
 				Definition: &v1alpha1.JSONSchemaProps{
-					Properties: map[string]v1alpha1.JSONSchemaProp{
-						"message": {
-							Type: "string",
-						},
-					},
+					Properties: properties,
 				},
-				Flow: asFlow(map[string]interface{}{
-					"from": map[string]interface{}{
-						"uri": "timer:tick",
-						"steps": []map[string]interface{}{
-							{
-								"set-body": map[string]interface{}{
-									"constant": "{{message}}",
-								},
-							},
-							{
-								"to": "kamelet:sink",
-							},
-						},
-					},
-				}),
+				Flow: asFlow(flow),
 			},
 		}
 		return TestClient().Create(TestContext, &kamelet)
 	}
 }
 
-func BindKameletTo(ns, name, from string, to corev1.ObjectReference, properties map[string]string) func() error {
-	return func() error {
-		kb := v1alpha1.KameletBinding{
-			ObjectMeta: metav1.ObjectMeta{
-				Namespace: ns,
-				Name:      name,
-			},
-			Spec: v1alpha1.KameletBindingSpec{
-				Source: v1alpha1.Endpoint{
-					Ref: &corev1.ObjectReference{
-						Kind:       "Kamelet",
-						APIVersion: v1alpha1.SchemeGroupVersion.String(),
-						Name:       from,
+func CreateTimerKamelet(ns string, name string) func() error {
+	props := map[string]v1alpha1.JSONSchemaProp{
+		"message": {
+			Type: "string",
+		},
+	}
+
+	flow := map[string]interface{}{
+		"from": map[string]interface{}{
+			"uri": "timer:tick",
+			"steps": []map[string]interface{}{
+				{
+					"set-body": map[string]interface{}{
+						"constant": "{{message}}",
 					},
-					Properties: asEndpointProperties(properties),
 				},
-				Sink: v1alpha1.Endpoint{
-					Ref:        &to,
-					Properties: asEndpointProperties(map[string]string{}),
+				{
+					"to": "kamelet:sink",
 				},
 			},
+		},
+	}
+
+	return CreateKamelet(ns, name, flow, props, nil)
+}
+
+func BindKameletTo(ns string, name string, from corev1.ObjectReference, to corev1.ObjectReference, sourceProperties map[string]string, sinkProperties map[string]string) func() error {
+	return BindKameletToWithErrorHandler(ns, name, from, to, sourceProperties, sinkProperties, nil)
+}
+
+func BindKameletToWithErrorHandler(ns string, name string, from corev1.ObjectReference, to corev1.ObjectReference, sourceProperties map[string]string, sinkProperties map[string]string, errorHandler map[string]interface{}) func() error {
+	return func() error {
+		kb := v1alpha1.NewKameletBinding(ns, name)
+		kb.Spec = v1alpha1.KameletBindingSpec{
+			Source: v1alpha1.Endpoint{
+				Ref:        &from,
+				Properties: asEndpointProperties(sourceProperties),
+			},
+			Sink: v1alpha1.Endpoint{
+				Ref:        &to,
+				Properties: asEndpointProperties(sinkProperties),
+			},
+		}
+		if errorHandler != nil {
+			kb.Spec.ErrorHandler = asErrorHandlerSpec(errorHandler)
 		}
 		return kubernetes.ReplaceResource(TestContext, TestClient(), &kb)
 	}
@@ -1242,6 +1540,16 @@ func asFlow(source map[string]interface{}) *v1.Flow {
 	}
 }
 
+func asErrorHandlerSpec(source map[string]interface{}) *v1alpha1.ErrorHandlerSpec {
+	bytes, err := json.Marshal(source)
+	if err != nil {
+		panic(err)
+	}
+	return &v1alpha1.ErrorHandlerSpec{
+		RawMessage: bytes,
+	}
+}
+
 func asEndpointProperties(props map[string]string) *v1alpha1.EndpointProperties {
 	bytes, err := json.Marshal(props)
 	if err != nil {
@@ -1252,6 +1560,16 @@ func asEndpointProperties(props map[string]string) *v1alpha1.EndpointProperties
 	}
 }
 
+func AsTraitConfiguration(props map[string]string) v1.TraitConfiguration {
+	bytes, err := json.Marshal(props)
+	if err != nil {
+		panic(err)
+	}
+	return v1.TraitConfiguration{
+		RawMessage: bytes,
+	}
+}
+
 /*
 	Namespace testing functions
 */
@@ -1453,19 +1771,10 @@ func NewTestNamespace(injectKnativeBroker bool) ctrl.Object {
 
 func GetOutputString(command *cobra.Command) string {
 	var buf bytes.Buffer
-	reader, writer, err := os.Pipe()
-	if err != nil {
-		panic(err)
-	}
 
-	command.SetOut(writer)
+	command.SetOut(&buf)
 	command.Execute()
 
-	writer.Close()
-	defer reader.Close()
-
-	buf.ReadFrom(reader)
-
 	return buf.String()
 }
 
