@@ -22,7 +22,13 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
-const TraitAnnotationPrefix = "trait.camel.apache.org/"
+const (
+	TraitAnnotationPrefix = "trait.camel.apache.org/"
+
+	OperatorIDAnnotation        = "camel.apache.org/operator.id"
+	SecondaryPlatformAnnotation = "camel.apache.org/secondary.platform"
+	PlatformSelectorAnnotation  = "camel.apache.org/platform.id"
+)
 
 // BuildStrategy specifies how the Build should be executed
 // +kubebuilder:validation:Enum=routine;pod
