@@ -116,10 +116,6 @@ const (
 	IntegrationPhaseWaitingForPlatform IntegrationPhase = "Waiting For Platform"
 	// IntegrationPhaseBuildingKit --
 	IntegrationPhaseBuildingKit IntegrationPhase = "Building Kit"
-	// IntegrationPhaseResolvingKit --
-	IntegrationPhaseResolvingKit IntegrationPhase = "Resolving Kit"
-	// IntegrationPhaseWaitingForBindings e.g Service Bindings --
-	IntegrationPhaseWaitingForBindings IntegrationPhase = "Waiting for Bindings"
 	// IntegrationPhaseDeploying --
 	IntegrationPhaseDeploying IntegrationPhase = "Deploying"
 	// IntegrationPhaseRunning --
@@ -139,8 +135,6 @@ const (
 	IntegrationConditionKnativeServiceAvailable IntegrationConditionType = "KnativeServiceAvailable"
 	// IntegrationConditionCronJobAvailable --
 	IntegrationConditionCronJobAvailable IntegrationConditionType = "CronJobAvailable"
-	// IntegrationConditionServiceBindingsCollectionReady --
-	IntegrationConditionServiceBindingsCollectionReady IntegrationConditionType = "ServiceBindingsCollectionReady"
 	// IntegrationConditionExposureAvailable --
 	IntegrationConditionExposureAvailable IntegrationConditionType = "ExposureAvailable"
 	// IntegrationConditionPrometheusAvailable --
@@ -188,14 +182,26 @@ const (
 	IntegrationConditionJolokiaAvailableReason string = "JolokiaAvailable"
 	// IntegrationConditionProbesAvailableReason --
 	IntegrationConditionProbesAvailableReason string = "ProbesAvailable"
-	// IntegrationConditionErrorReason --
-	IntegrationConditionErrorReason string = "Error"
+
+	// IntegrationConditionKnativeServiceReadyReason --
+	IntegrationConditionKnativeServiceReadyReason string = "KnativeServiceReady"
+	// IntegrationConditionDeploymentReadyReason --
+	IntegrationConditionDeploymentReadyReason string = "DeploymentReady"
+	// IntegrationConditionDeploymentProgressingReason --
+	IntegrationConditionDeploymentProgressingReason string = "DeploymentProgressing"
 	// IntegrationConditionCronJobCreatedReason --
 	IntegrationConditionCronJobCreatedReason string = "CronJobCreated"
-	// IntegrationConditionReplicaSetReadyReason --
-	IntegrationConditionReplicaSetReadyReason string = "ReplicaSetReady"
-	// IntegrationConditionReplicaSetNotReadyReason --
-	IntegrationConditionReplicaSetNotReadyReason string = "ReplicaSetNotReady"
+	// IntegrationConditionCronJobActiveReason --
+	IntegrationConditionCronJobActiveReason string = "CronJobActive"
+	// IntegrationConditionLastJobSucceededReason --
+	IntegrationConditionLastJobSucceededReason string = "LastJobSucceeded"
+	// IntegrationConditionLastJobFailedReason --
+	IntegrationConditionLastJobFailedReason string = "LastJobFailed"
+	// IntegrationConditionErrorReason --
+	IntegrationConditionErrorReason string = "Error"
+
+	// IntegrationConditionUnsupportedLanguageReason --
+	IntegrationConditionUnsupportedLanguageReason string = "UnsupportedLanguage"
 
 	// IntegrationConditionKameletsAvailable --
 	IntegrationConditionKameletsAvailable IntegrationConditionType = "KameletsAvailable"
@@ -219,7 +225,7 @@ type IntegrationCondition struct {
 	FirstTruthyTime *metav1.Time `json:"firstTruthyTime,omitempty"`
 	// The reason for the condition's last transition.
 	Reason string `json:"reason,omitempty"`
-	// A human readable message indicating details about the transition.
+	// A human-readable message indicating details about the transition.
 	Message string `json:"message,omitempty"`
 }
 type PodSpecTemplate struct {
