@@ -19,6 +19,7 @@ package builder
 
 import (
 	"context"
+	"errors"
 	"os"
 	"path"
 	"sort"
@@ -86,14 +87,11 @@ func (t *builderTask) Do(ctx context.Context) v1.BuildStatus {
 		})
 	}
 
-	steps := make([]Step, 0)
-	for _, step := range t.task.Steps {
-		s, ok := stepsByID[step]
-		if !ok {
-			log.Info("Skipping unknown build step", "step", step)
-			continue
-		}
-		steps = append(steps, s)
+	steps, err := StepsFrom(t.task.Steps...)
+	if err != nil {
+		t.log.Errorf(err, "invalid builder steps: %s", t.task.Steps)
+		result.Failed(err)
+		return result
 	}
 	// Sort steps by phase
 	sort.SliceStable(steps, func(i, j int) bool {
@@ -107,7 +105,7 @@ steps:
 		select {
 
 		case <-ctx.Done():
-			if ctx.Err() == context.Canceled {
+			if errors.Is(ctx.Err(), context.Canceled) {
 				// Context canceled
 				result.Phase = v1.BuildPhaseInterrupted
 			} else {
