@@ -18,10 +18,13 @@ limitations under the License.
 package client
 
 import (
+	"fmt"
 	"io/ioutil"
 	"os"
 	"path/filepath"
 
+	camelv1 "github.com/apache/camel-k/pkg/client/camel/clientset/versioned/typed/camel/v1"
+	camelv1alpha1 "github.com/apache/camel-k/pkg/client/camel/clientset/versioned/typed/camel/v1alpha1"
 	user "github.com/mitchellh/go-homedir"
 	"github.com/pkg/errors"
 	"github.com/sirupsen/logrus"
@@ -42,6 +45,7 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/manager"
 
 	"github.com/apache/camel-k/pkg/apis"
+	camel "github.com/apache/camel-k/pkg/client/camel/clientset/versioned"
 )
 
 const (
@@ -53,6 +57,8 @@ const (
 type Client interface {
 	controller.Client
 	kubernetes.Interface
+	CamelV1() camelv1.CamelV1Interface
+	CamelV1alpha1() camelv1alpha1.CamelV1alpha1Interface
 	GetScheme() *runtime.Scheme
 	GetConfig() *rest.Config
 	GetCurrentNamespace(kubeConfig string) (string, error)
@@ -71,10 +77,22 @@ type Provider struct {
 type defaultClient struct {
 	controller.Client
 	kubernetes.Interface
+	camel  camel.Interface
 	scheme *runtime.Scheme
 	config *rest.Config
 }
 
+// Check interface compliance
+var _ Client = &defaultClient{}
+
+func (c *defaultClient) CamelV1() camelv1.CamelV1Interface {
+	return c.camel.CamelV1()
+}
+
+func (c *defaultClient) CamelV1alpha1() camelv1alpha1.CamelV1alpha1Interface {
+	return c.camel.CamelV1alpha1()
+}
+
 func (c *defaultClient) GetScheme() *runtime.Scheme {
 	return c.scheme
 }
@@ -114,6 +132,11 @@ func NewClient(fastDiscovery bool) (Client, error) {
 		return nil, err
 	}
 
+	var camelClientset camel.Interface
+	if camelClientset, err = camel.NewForConfig(cfg); err != nil {
+		return nil, err
+	}
+
 	var mapper meta.RESTMapper
 	if fastDiscovery {
 		mapper = newFastDiscoveryRESTMapper(cfg)
@@ -132,6 +155,7 @@ func NewClient(fastDiscovery bool) (Client, error) {
 	return &defaultClient{
 		Client:    dynClient,
 		Interface: clientset,
+		camel:     camelClientset,
 		scheme:    clientOptions.Scheme,
 		config:    cfg,
 	}, nil
@@ -144,9 +168,15 @@ func FromManager(manager manager.Manager) (Client, error) {
 	if clientset, err = kubernetes.NewForConfig(manager.GetConfig()); err != nil {
 		return nil, err
 	}
+	var camelClientset camel.Interface
+	if camelClientset, err = camel.NewForConfig(manager.GetConfig()); err != nil {
+		return nil, err
+	}
+
 	return &defaultClient{
 		Client:    manager.GetClient(),
 		Interface: clientset,
+		camel:     camelClientset,
 		scheme:    manager.GetScheme(),
 		config:    manager.GetConfig(),
 	}, nil
@@ -175,6 +205,7 @@ func getDefaultKubeConfigFile() (string, error) {
 	if err != nil {
 		return "", err
 	}
+
 	return filepath.Join(dir, ".kube", "config"), nil
 }
 
@@ -214,7 +245,10 @@ func GetCurrentNamespace(kubeconfig string) (string, error) {
 		return "", err
 	}
 
-	clientcmdconfig := decoded.(*clientcmdapi.Config)
+	clientcmdconfig, ok := decoded.(*clientcmdapi.Config)
+	if !ok {
+		return "", fmt.Errorf("type assertion failed: %v", decoded)
+	}
 
 	cc := clientcmd.NewDefaultClientConfig(*clientcmdconfig, &clientcmd.ConfigOverrides{})
 	ns, _, err := cc.Namespace()
