@@ -127,10 +127,11 @@ func newCmdInstall(rootCmdOptions *RootCmdOptions) (*cobra.Command, *installCmdO
 	cmd.Flags().Bool("monitoring", false, "To enable or disable the operator monitoring")
 	cmd.Flags().Int("monitoring-port", 8080, "The port of the metrics endpoint")
 
-	// Pod settings
+	// Operator settings
 	cmd.Flags().StringArray("toleration", nil, "Add a Toleration to the operator Pod")
 	cmd.Flags().StringArray("node-selector", nil, "Add a NodeSelector to the operator Pod")
-	cmd.Flags().StringArray("operator-resources", nil, "Define the resources requests and limits assigned to the operator Pod as <requestType.requestResource=value> (ie, limits.memory=256Mi)")
+	cmd.Flags().StringArray("operator-resources", nil, "Define the resources requests and limits assigned to the operator Pod as <requestType.requestResource=value> (i.e., limits.memory=256Mi)")
+	cmd.Flags().StringArray("operator-env-vars", nil, "Add an environment variable to set in the operator Pod(s), as <name=value>")
 
 	// save
 	cmd.Flags().Bool("save", false, "Save the install parameters into the default kamel configuration file (kamel-config.yaml)")
@@ -183,8 +184,9 @@ type installCmdOptions struct {
 	NodeSelectors           []string `mapstructure:"node-selectors"`
 	HTTPProxySecret         string   `mapstructure:"http-proxy-secret"`
 	ResourcesRequirements   []string `mapstructure:"operator-resources"`
+	EnvVars                 []string `mapstructure:"operator-env-vars"`
 
-	registry         v1.IntegrationPlatformRegistrySpec
+	registry         v1.RegistrySpec
 	registryAuth     registry.Auth
 	RegistryAuthFile string `mapstructure:"registry-auth-file"`
 
@@ -229,7 +231,7 @@ func (o *installCmdOptions) install(cobraCmd *cobra.Command, _ []string) error {
 			fmt.Fprintln(cobraCmd.OutOrStdout(), "OLM is available in the cluster")
 			var installed bool
 			if installed, err = olm.Install(o.Context, olmClient, o.Namespace, o.Global, o.olmOptions, collection,
-				o.Tolerations, o.NodeSelectors, o.ResourcesRequirements); err != nil {
+				o.Tolerations, o.NodeSelectors, o.ResourcesRequirements, o.EnvVars); err != nil {
 				return err
 			}
 			if !installed {
@@ -283,6 +285,7 @@ func (o *installCmdOptions) install(cobraCmd *cobra.Command, _ []string) error {
 				Tolerations:           o.Tolerations,
 				NodeSelectors:         o.NodeSelectors,
 				ResourcesRequirements: o.ResourcesRequirements,
+				EnvVars:               o.EnvVars,
 			}
 			err = install.OperatorOrCollect(o.Context, c, cfg, collection, o.Force)
 			if err != nil {
@@ -360,7 +363,7 @@ func (o *installCmdOptions) install(cobraCmd *cobra.Command, _ []string) error {
 			platform.Spec.Build.BaseImage = o.BaseImage
 		}
 		if o.BuildStrategy != "" {
-			platform.Spec.Build.BuildStrategy = v1.IntegrationPlatformBuildStrategy(o.BuildStrategy)
+			platform.Spec.Build.BuildStrategy = v1.BuildStrategy(o.BuildStrategy)
 		}
 		if o.BuildPublishStrategy != "" {
 			platform.Spec.Build.PublishStrategy = v1.IntegrationPlatformBuildPublishStrategy(o.BuildPublishStrategy)
@@ -496,20 +499,24 @@ func (o *installCmdOptions) printOutput(collection *kubernetes.Collection) error
 
 // nolint:errcheck
 func (o *installCmdOptions) waitForPlatformReady(cmd *cobra.Command, platform *v1.IntegrationPlatform) error {
+	c, err := o.GetCmdClient()
+	if err != nil {
+		return err
+	}
+
 	handler := func(i *v1.IntegrationPlatform) bool {
 		if i.Status.Phase == v1.IntegrationPlatformPhaseReady || i.Status.Phase == v1.IntegrationPlatformPhaseError {
 			return false
 		}
-
 		return true
 	}
 
-	go watch.HandleIntegrationPlatformEvents(o.Context, platform, func(event *corev1.Event) bool {
+	go watch.HandleIntegrationPlatformEvents(o.Context, c, platform, func(event *corev1.Event) bool {
 		fmt.Fprintln(cmd.OutOrStdout(), event.Message)
 		return true
 	})
 
-	return watch.HandlePlatformStateChanges(o.Context, platform, handler)
+	return watch.HandlePlatformStateChanges(o.Context, c, platform, handler)
 }
 
 func (o *installCmdOptions) decode(cmd *cobra.Command, _ []string) error {
@@ -574,7 +581,7 @@ func (o *installCmdOptions) validate(_ *cobra.Command, _ []string) error {
 
 	if o.BuildStrategy != "" {
 		found := false
-		for _, s := range v1.IntegrationPlatformBuildStrategies {
+		for _, s := range v1.BuildStrategies {
 			if string(s) == o.BuildStrategy {
 				found = true
 				break
@@ -582,7 +589,7 @@ func (o *installCmdOptions) validate(_ *cobra.Command, _ []string) error {
 		}
 		if !found {
 			var strategies []string
-			for _, s := range v1.IntegrationPlatformBuildStrategies {
+			for _, s := range v1.BuildStrategies {
 				strategies = append(strategies, string(s))
 			}
 			return fmt.Errorf("unknown build strategy: %s. One of [%s] is expected", o.BuildStrategy, strings.Join(strategies, ", "))
