@@ -55,9 +55,7 @@ import (
 	"github.com/apache/camel-k/pkg/util/watch"
 )
 
-var (
-	traitConfigRegexp = regexp.MustCompile(`^([a-z0-9-]+)((?:\.[a-z0-9-]+)+)=(.*)$`)
-)
+var traitConfigRegexp = regexp.MustCompile(`^([a-z0-9-]+)((?:\.[a-z0-9-]+)+)=(.*)$`)
 
 func newCmdRun(rootCmdOptions *RootCmdOptions) (*cobra.Command, *runCmdOptions) {
 	options := runCmdOptions{
@@ -75,7 +73,7 @@ func newCmdRun(rootCmdOptions *RootCmdOptions) (*cobra.Command, *runCmdOptions)
 	}
 
 	cmd.Flags().String("name", "", "The integration name")
-	cmd.Flags().StringArrayP("connect", "c", nil, "A ServiceBinding or Provisioned Service that the integration should bind to, specified as [[apigroup/]version:]kind:[namespace/]name")
+	cmd.Flags().StringArrayP("connect", "c", nil, "A Service that the integration should bind to, specified as [[apigroup/]version:]kind:[namespace/]name")
 	cmd.Flags().StringArrayP("dependency", "d", nil, "A dependency that should be included, e.g., \"-d camel-mail\" for a Camel component, or \"-d mvn:org.my:app:1.0\" for a Maven dependency")
 	cmd.Flags().BoolP("wait", "w", false, "Wait for the integration to be running")
 	cmd.Flags().StringP("kit", "k", "", "The kit used to run the integration")
@@ -98,6 +96,7 @@ func newCmdRun(rootCmdOptions *RootCmdOptions) (*cobra.Command, *runCmdOptions)
 	cmd.Flags().StringArrayP("volume", "v", nil, "Mount a volume into the integration container. E.g \"-v pvcname:/container/path\"")
 	cmd.Flags().StringArrayP("env", "e", nil, "Set an environment variable in the integration container. E.g \"-e MY_VAR=my-value\"")
 	cmd.Flags().StringArray("property-file", nil, "[Deprecated] Bind a property file to the integration. E.g. \"--property-file integration.properties\"")
+	cmd.Flags().StringArray("annotation", nil, "Add an annotation to the integration. E.g. \"--annotation my.company=hello\"")
 	cmd.Flags().StringArray("label", nil, "Add a label to the integration. E.g. \"--label my.company=hello\"")
 	cmd.Flags().StringArray("source", nil, "Add source file to your integration, this is added to the list of files listed as arguments of the command")
 	cmd.Flags().String("pod-template", "", "The path of the YAML file containing a PodSpec template to be used for the Integration pods")
@@ -137,14 +136,14 @@ type runCmdOptions struct {
 	Traits          []string `mapstructure:"traits" yaml:",omitempty"`
 	Volumes         []string `mapstructure:"volumes" yaml:",omitempty"`
 	EnvVars         []string `mapstructure:"envs" yaml:",omitempty"`
-	// Deprecated: PropertyFiles has been deprecated in 1.5
+	// Deprecated: since 1.5
 	PropertyFiles []string `mapstructure:"property-files" yaml:",omitempty"`
 	Labels        []string `mapstructure:"labels" yaml:",omitempty"`
+	Annotations   []string `mapstructure:"annotations" yaml:",omitempty"`
 	Sources       []string `mapstructure:"sources" yaml:",omitempty"`
 }
 
 func (o *runCmdOptions) decode(cmd *cobra.Command, args []string) error {
-
 	// *************************************************************************
 	//
 	// WARNING: this is an hack, well a huge one
@@ -256,6 +255,13 @@ func (o *runCmdOptions) validate() error {
 		}
 	}
 
+	for _, annotation := range o.Annotations {
+		parts := strings.SplitN(annotation, "=", 2)
+		if len(parts) != 2 {
+			return fmt.Errorf(`invalid annotation specification %s. Expected "<annotationkey>=<annotationvalue>"`, annotation)
+		}
+	}
+
 	return nil
 }
 
@@ -276,7 +282,7 @@ func (o *runCmdOptions) run(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
-	catalog := trait.NewCatalog(o.Context, c)
+	catalog := trait.NewCatalog(c)
 	tp := catalog.ComputeTraitsProperties()
 	for _, t := range o.Traits {
 		kv := strings.SplitN(t, "=", 2)
@@ -287,13 +293,13 @@ func (o *runCmdOptions) run(cmd *cobra.Command, args []string) error {
 		}
 	}
 
-	integration, err := o.createOrUpdateIntegration(c, args, catalog)
+	integration, err := o.createOrUpdateIntegration(cmd, c, args, catalog)
 	if err != nil {
 		return err
 	}
 
 	if o.Dev {
-		cs := make(chan os.Signal)
+		cs := make(chan os.Signal, 1)
 		signal.Notify(cs, os.Interrupt, syscall.SIGTERM)
 		go func() {
 			<-cs
@@ -319,14 +325,14 @@ func (o *runCmdOptions) run(cmd *cobra.Command, args []string) error {
 	}
 	if o.Logs || o.Dev || o.Wait {
 		// nolint: errcheck
-		go watch.HandleIntegrationEvents(o.Context, integration, func(event *corev1.Event) bool {
+		go watch.HandleIntegrationEvents(o.Context, c, integration, func(event *corev1.Event) bool {
 			fmt.Fprintln(cmd.OutOrStdout(), event.Message)
 			return true
 		})
 	}
 	if o.Wait || o.Dev {
 		for {
-			integrationPhase, err := o.waitForIntegrationReady(cmd, integration)
+			integrationPhase, err := o.waitForIntegrationReady(cmd, c, integration)
 			if err != nil {
 				return err
 			}
@@ -383,8 +389,7 @@ func (o *runCmdOptions) postRun(cmd *cobra.Command, args []string) error {
 	return nil
 }
 
-// nolint:errcheck
-func (o *runCmdOptions) waitForIntegrationReady(cmd *cobra.Command, integration *v1.Integration) (*v1.IntegrationPhase, error) {
+func (o *runCmdOptions) waitForIntegrationReady(cmd *cobra.Command, c client.Client, integration *v1.Integration) (*v1.IntegrationPhase, error) {
 	handler := func(i *v1.Integration) bool {
 		//
 		// TODO when we add health checks, we should Wait until they are passed
@@ -400,7 +405,7 @@ func (o *runCmdOptions) waitForIntegrationReady(cmd *cobra.Command, integration
 		return true
 	}
 
-	return watch.HandleIntegrationStateChanges(o.Context, integration, handler)
+	return watch.HandleIntegrationStateChanges(o.Context, c, integration, handler)
 }
 
 func (o *runCmdOptions) syncIntegration(cmd *cobra.Command, c client.Client, sources []string, catalog *trait.Catalog) error {
@@ -436,12 +441,13 @@ func (o *runCmdOptions) syncIntegration(cmd *cobra.Command, c client.Client, sou
 						newCmd.SetErr(cmd.ErrOrStderr())
 						if err != nil {
 							fmt.Println("Unable to sync integration: ", err.Error())
+
 							continue
 						}
 						newCmd.Args = o.validateArgs
 						newCmd.PreRunE = o.decode
 						newCmd.RunE = func(cmd *cobra.Command, args []string) error {
-							_, err := o.createOrUpdateIntegration(c, sources, catalog)
+							_, err := o.createOrUpdateIntegration(cmd, c, sources, catalog)
 							return err
 						}
 						newCmd.PostRunE = nil
@@ -465,7 +471,7 @@ func (o *runCmdOptions) syncIntegration(cmd *cobra.Command, c client.Client, sou
 }
 
 // nolint: gocyclo
-func (o *runCmdOptions) createOrUpdateIntegration(c client.Client, sources []string, catalog *trait.Catalog) (*v1.Integration, error) {
+func (o *runCmdOptions) createOrUpdateIntegration(cmd *cobra.Command, c client.Client, sources []string, catalog *trait.Catalog) (*v1.Integration, error) {
 	namespace := o.Namespace
 	name := o.GetIntegrationName(sources)
 
@@ -486,11 +492,12 @@ func (o *runCmdOptions) createOrUpdateIntegration(c client.Client, sources []str
 
 	existing := &v1.Integration{}
 	err := c.Get(o.Context, ctrl.ObjectKeyFromObject(integration), existing)
-	if err == nil {
+	switch {
+	case err == nil:
 		integration = existing.DeepCopy()
-	} else if k8serrors.IsNotFound(err) {
+	case k8serrors.IsNotFound(err):
 		existing = nil
-	} else {
+	default:
 		return nil, err
 	}
 
@@ -520,6 +527,16 @@ func (o *runCmdOptions) createOrUpdateIntegration(c client.Client, sources []str
 		}
 	}
 
+	for _, annotation := range o.Annotations {
+		parts := strings.SplitN(annotation, "=", 2)
+		if len(parts) == 2 {
+			if integration.Annotations == nil {
+				integration.Annotations = make(map[string]string)
+			}
+			integration.Annotations[parts[0]] = parts[1]
+		}
+	}
+
 	srcs := make([]string, 0, len(sources)+len(o.Sources))
 	srcs = append(srcs, sources...)
 	srcs = append(srcs, o.Sources...)
@@ -575,34 +592,34 @@ func (o *runCmdOptions) createOrUpdateIntegration(c client.Client, sources []str
 		// Deprecated: making it compatible with newer mechanism
 		o.Properties = append(o.Properties, "file:"+item)
 	}
-	for _, item := range o.Properties {
-		props, err := extractProperties(item)
+
+	props, err := mergePropertiesWithPrecedence(o.Properties)
+	if err != nil {
+		return nil, err
+	}
+	for _, key := range props.Keys() {
+		kv := fmt.Sprintf("%s=%s", key, props.GetString(key, ""))
+		propsTraits, err := convertToTraitParameter(kv, "camel.properties")
 		if err != nil {
 			return nil, err
 		}
-		if err := addIntegrationProperties(props, &integration.Spec); err != nil {
-			return nil, err
-		}
+		o.Traits = append(o.Traits, propsTraits...)
 	}
+
 	// convert each build configuration to a builder trait property
-	for _, item := range o.BuildProperties {
-		props, err := extractProperties(item)
+	buildProps, err := mergePropertiesWithPrecedence(o.BuildProperties)
+	if err != nil {
+		return nil, err
+	}
+	for _, key := range buildProps.Keys() {
+		kv := fmt.Sprintf("%s=%s", key, buildProps.GetString(key, ""))
+		buildPropsTraits, err := convertToTraitParameter(kv, "builder.properties")
 		if err != nil {
 			return nil, err
 		}
-		for _, k := range props.Keys() {
-			v, ok := props.Get(k)
-			if ok {
-				entry, err := property.EncodePropertyFileEntry(k, v)
-				if err != nil {
-					return nil, err
-				}
-				o.Traits = append(o.Traits, fmt.Sprintf("builder.properties=%s", entry))
-			} else {
-				return nil, err
-			}
-		}
+		o.Traits = append(o.Traits, buildPropsTraits...)
 	}
+
 	for _, item := range o.Configs {
 		if config, parseErr := ParseConfigOption(item); parseErr == nil {
 			if applyConfigOptionErr := ApplyConfigOption(config, &integration.Spec, c, namespace, o.Compression); applyConfigOptionErr != nil {
@@ -622,7 +639,7 @@ func (o *runCmdOptions) createOrUpdateIntegration(c client.Client, sources []str
 		integration.Spec.AddConfiguration("volume", item)
 	}
 	for _, item := range o.EnvVars {
-		integration.Spec.AddConfiguration("env", item)
+		o.Traits = append(o.Traits, fmt.Sprintf("environment.vars=%s", item))
 	}
 
 	if err := o.configureTraits(integration, o.Traits, catalog); err != nil {
@@ -637,7 +654,7 @@ func (o *runCmdOptions) createOrUpdateIntegration(c client.Client, sources []str
 		if err != nil {
 			return nil, err
 		}
-		fmt.Print(string(data))
+		fmt.Fprint(cmd.OutOrStdout(), string(data))
 		return nil, nil
 
 	case "json":
@@ -645,7 +662,7 @@ func (o *runCmdOptions) createOrUpdateIntegration(c client.Client, sources []str
 		if err != nil {
 			return nil, err
 		}
-		fmt.Print(string(data))
+		fmt.Fprint(cmd.OutOrStdout(), string(data))
 		return nil, nil
 
 	default:
@@ -687,18 +704,26 @@ func addResource(resourceLocation string, integrationSpec *v1.IntegrationSpec, e
 	return nil
 }
 
-// The function parse the value and if it is a file (file:/path/), it will parse as property file
-// otherwise return a single property built from the item passed as `key=value`
-func extractProperties(value string) (*properties.Properties, error) {
-	if !strings.HasPrefix(value, "file:") {
-		return keyValueProps(value)
+func convertToTraitParameter(value, traitParameter string) ([]string, error) {
+	traits := make([]string, 0)
+	props, err := extractProperties(value)
+	if err != nil {
+		return nil, err
+	}
+	for _, k := range props.Keys() {
+		v, ok := props.Get(k)
+		if ok {
+			entry, err := property.EncodePropertyFileEntry(k, v)
+			if err != nil {
+				return nil, err
+			}
+			traits = append(traits, fmt.Sprintf("%s=%s", traitParameter, entry))
+		} else {
+			return nil, err
+		}
 	}
-	// we already validated the existence of files during validate()
-	return loadPropertyFile(strings.Replace(value, "file:", "", 1))
-}
 
-func keyValueProps(value string) (*properties.Properties, error) {
-	return properties.Load([]byte(value), properties.UTF8)
+	return traits, nil
 }
 
 func (o *runCmdOptions) GetIntegrationName(sources []string) string {
@@ -715,7 +740,7 @@ func (o *runCmdOptions) GetIntegrationName(sources []string) string {
 func (o *runCmdOptions) configureTraits(integration *v1.Integration, options []string, catalog *trait.Catalog) error {
 	// configure ServiceBinding trait
 	for _, sb := range o.Connects {
-		bindings := fmt.Sprintf("service-binding.service-bindings=%s", sb)
+		bindings := fmt.Sprintf("service-binding.services=%s", sb)
 		options = append(options, bindings)
 	}
 	traits, err := configureTraits(options, catalog)
@@ -728,21 +753,6 @@ func (o *runCmdOptions) configureTraits(integration *v1.Integration, options []s
 	return nil
 }
 
-func addIntegrationProperties(props *properties.Properties, spec *v1.IntegrationSpec) error {
-	for _, k := range props.Keys() {
-		v, _ := props.Get(k)
-		entry, err := property.EncodePropertyFileEntry(k, v)
-		if err != nil {
-			return err
-		}
-		spec.AddConfiguration(
-			"property",
-			entry,
-		)
-	}
-	return nil
-}
-
 func loadPropertyFile(fileName string) (*properties.Properties, error) {
 	file, err := ioutil.ReadFile(fileName)
 	if err != nil {
@@ -852,7 +862,6 @@ func configureTrait(config map[string]interface{}, trait interface{}) error {
 			Result:           &trait,
 		},
 	)
-
 	if err != nil {
 		return err
 	}
