@@ -84,7 +84,7 @@ func ResolveSources(ctx context.Context, locations []string, compress bool) ([]S
 			}
 
 			switch {
-			case u.Scheme == "gist" || strings.HasPrefix(location, "https://gist.github.com/"):
+			case u.Scheme == gistScheme || strings.HasPrefix(location, "https://gist.github.com/"):
 				var tc *http.Client
 
 				if token, ok := os.LookupEnv("GITHUB_TOKEN"); ok {
@@ -107,7 +107,7 @@ func ResolveSources(ctx context.Context, locations []string, compress bool) ([]S
 				}
 
 				if gistID == "" {
-					return sources, fmt.Errorf("unable to determing gist id from %s", location)
+					return sources, fmt.Errorf("unable to determining gist id from %s", location)
 				}
 
 				gists, _, err := gc.Gists.Get(ctx, gistID)
@@ -133,7 +133,7 @@ func ResolveSources(ctx context.Context, locations []string, compress bool) ([]S
 					}
 					sources = append(sources, answer)
 				}
-			case u.Scheme == "github":
+			case u.Scheme == githubScheme:
 				answer := Source{
 					Name:     path.Base(location),
 					Origin:   location,
@@ -149,7 +149,7 @@ func ResolveSources(ctx context.Context, locations []string, compress bool) ([]S
 					return sources, err
 				}
 				sources = append(sources, answer)
-			case u.Scheme == "http":
+			case u.Scheme == httpScheme:
 				answer := Source{
 					Name:     path.Base(location),
 					Origin:   location,
@@ -165,7 +165,7 @@ func ResolveSources(ctx context.Context, locations []string, compress bool) ([]S
 					return sources, err
 				}
 				sources = append(sources, answer)
-			case u.Scheme == "https":
+			case u.Scheme == httpsScheme:
 				answer := Source{
 					Name:     path.Base(location),
 					Origin:   location,
@@ -182,7 +182,7 @@ func ResolveSources(ctx context.Context, locations []string, compress bool) ([]S
 				}
 				sources = append(sources, answer)
 			default:
-				return sources, fmt.Errorf("Missing file or unsupported scheme in %s", location)
+				return sources, fmt.Errorf("missing file or unsupported scheme in %s", location)
 			}
 		}
 	}
