@@ -56,6 +56,7 @@ func (action *initializeAction) Handle(ctx context.Context, integration *v1.Inte
 	}
 
 	if integration.Status.IntegrationKit == nil {
+		// nolint: staticcheck
 		if integration.Spec.IntegrationKit == nil && integration.Spec.Kit != "" {
 			// TODO: temporary fallback until deprecated field gets removed
 			integration.Spec.IntegrationKit = &corev1.ObjectReference{
@@ -68,7 +69,7 @@ func (action *initializeAction) Handle(ctx context.Context, integration *v1.Inte
 			kitName := integration.Spec.IntegrationKit.Name
 
 			if kitNamespace == "" {
-				pl, err := platform.GetCurrent(ctx, action.client, integration.Namespace)
+				pl, err := platform.GetForResource(ctx, action.client, integration)
 				if err != nil && !k8serrors.IsNotFound(err) {
 					return nil, err
 				}
@@ -77,7 +78,7 @@ func (action *initializeAction) Handle(ctx context.Context, integration *v1.Inte
 				}
 			}
 			kit := v1.NewIntegrationKit(kitNamespace, kitName)
-			integration.SetIntegrationKit(&kit)
+			integration.SetIntegrationKit(kit)
 		} else {
 			integration.Status.IntegrationKit = nil
 		}
@@ -86,7 +87,8 @@ func (action *initializeAction) Handle(ctx context.Context, integration *v1.Inte
 	integration.Status.Phase = v1.IntegrationPhaseBuildingKit
 	integration.Status.Version = defaults.Version
 	if timestamp := integration.Status.InitializationTimestamp; timestamp == nil || timestamp.IsZero() {
-		now := metav1.Now()
+		// Round to second precision, as meta.Time fields are marshalled in RFC3339 format
+		now := metav1.Now().Rfc3339Copy()
 		integration.Status.InitializationTimestamp = &now
 	}
 
