@@ -20,13 +20,13 @@ package integration
 import (
 	"context"
 
-	"github.com/apache/camel-k/pkg/client"
-	"github.com/apache/camel-k/pkg/platform"
-	"github.com/apache/camel-k/pkg/util/knative"
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 
 	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/pkg/client"
+	"github.com/apache/camel-k/pkg/platform"
 	"github.com/apache/camel-k/pkg/trait"
+	"github.com/apache/camel-k/pkg/util/knative"
 )
 
 // NewPlatformSetupAction creates a new platform-setup action
@@ -55,7 +55,7 @@ func (action *platformSetupAction) Handle(ctx context.Context, integration *v1.I
 		return nil, err
 	}
 
-	pl, err := platform.GetCurrentPlatform(ctx, action.client, integration.Namespace)
+	pl, err := platform.GetForResource(ctx, action.client, integration)
 	if err != nil && !k8serrors.IsNotFound(err) {
 		return nil, err
 	} else if pl != nil {
@@ -78,6 +78,10 @@ func determineBestProfile(ctx context.Context, c client.Client, integration *v1.
 		// Use platform profile if set
 		return p.Status.Profile
 	}
+	if p.Spec.Profile != "" {
+		// Use platform spec profile if set
+		return p.Spec.Profile
+	}
 	if knative.IsEnabledInNamespace(ctx, c, integration.Namespace) {
 		return v1.TraitProfileKnative
 	}
