@@ -19,29 +19,29 @@ package integrationkit
 
 import (
 	"context"
-
-	camelevent "github.com/apache/camel-k/pkg/event"
-	"github.com/apache/camel-k/pkg/platform"
-	"k8s.io/client-go/tools/record"
-
-	"github.com/apache/camel-k/pkg/util/digest"
-	"github.com/apache/camel-k/pkg/util/log"
+	"fmt"
 
 	"k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/runtime"
+	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/apimachinery/pkg/types"
-	k8sclient "sigs.k8s.io/controller-runtime/pkg/client"
+	"k8s.io/client-go/tools/record"
 
+	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 	"sigs.k8s.io/controller-runtime/pkg/controller"
 	"sigs.k8s.io/controller-runtime/pkg/event"
 	"sigs.k8s.io/controller-runtime/pkg/handler"
 	"sigs.k8s.io/controller-runtime/pkg/manager"
-	"sigs.k8s.io/controller-runtime/pkg/predicate"
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 	"sigs.k8s.io/controller-runtime/pkg/source"
 
 	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/pkg/client"
+	camelevent "github.com/apache/camel-k/pkg/event"
+	"github.com/apache/camel-k/pkg/platform"
+	"github.com/apache/camel-k/pkg/util/digest"
+	"github.com/apache/camel-k/pkg/util/log"
+	"github.com/apache/camel-k/pkg/util/monitoring"
 )
 
 // Add creates a new IntegrationKit Controller and adds it to the Manager. The Manager will set fields on the Controller
@@ -56,11 +56,18 @@ func Add(mgr manager.Manager) error {
 
 // newReconciler returns a new reconcile.Reconciler
 func newReconciler(mgr manager.Manager, c client.Client) reconcile.Reconciler {
-	return &ReconcileIntegrationKit{
-		client:   c,
-		scheme:   mgr.GetScheme(),
-		recorder: mgr.GetEventRecorderFor("camel-k-integration-kit-controller"),
-	}
+	return monitoring.NewInstrumentedReconciler(
+		&reconcileIntegrationKit{
+			client:   c,
+			scheme:   mgr.GetScheme(),
+			recorder: mgr.GetEventRecorderFor("camel-k-integration-kit-controller"),
+		},
+		schema.GroupVersionKind{
+			Group:   v1.SchemeGroupVersion.Group,
+			Version: v1.SchemeGroupVersion.Version,
+			Kind:    v1.IntegrationKitKind,
+		},
+	)
 }
 
 // add adds a new Controller to mgr with r as the reconcile.Reconciler
@@ -72,21 +79,30 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 	}
 
 	// Watch for changes to primary resource IntegrationKit
-	err = c.Watch(&source.Kind{Type: &v1.IntegrationKit{}}, &handler.EnqueueRequestForObject{}, predicate.Funcs{
-		UpdateFunc: func(e event.UpdateEvent) bool {
-			oldIntegrationKit := e.ObjectOld.(*v1.IntegrationKit)
-			newIntegrationKit := e.ObjectNew.(*v1.IntegrationKit)
-			// Ignore updates to the integration kit status in which case metadata.Generation
-			// does not change, or except when the integration kit phase changes as it's used
-			// to transition from one phase to another
-			return oldIntegrationKit.Generation != newIntegrationKit.Generation ||
-				oldIntegrationKit.Status.Phase != newIntegrationKit.Status.Phase
+	err = c.Watch(&source.Kind{Type: &v1.IntegrationKit{}},
+		&handler.EnqueueRequestForObject{},
+		platform.FilteringFuncs{
+			UpdateFunc: func(e event.UpdateEvent) bool {
+				oldIntegrationKit, ok := e.ObjectOld.(*v1.IntegrationKit)
+				if !ok {
+					return false
+				}
+				newIntegrationKit, ok := e.ObjectNew.(*v1.IntegrationKit)
+				if !ok {
+					return false
+				}
+				// Ignore updates to the integration kit status in which case metadata.Generation
+				// does not change, or except when the integration kit phase changes as it's used
+				// to transition from one phase to another
+				return oldIntegrationKit.Generation != newIntegrationKit.Generation ||
+					oldIntegrationKit.Status.Phase != newIntegrationKit.Status.Phase
+			},
+			DeleteFunc: func(e event.DeleteEvent) bool {
+				// Evaluates to false if the object has been confirmed deleted
+				return !e.DeleteStateUnknown
+			},
 		},
-		DeleteFunc: func(e event.DeleteEvent) bool {
-			// Evaluates to false if the object has been confirmed deleted
-			return !e.DeleteStateUnknown
-		},
-	})
+	)
 	if err != nil {
 		return err
 	}
@@ -97,38 +113,49 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 			IsController: true,
 			OwnerType:    &v1.IntegrationKit{},
 		},
-		predicate.Funcs{
+		platform.FilteringFuncs{
 			UpdateFunc: func(e event.UpdateEvent) bool {
-				oldBuild := e.ObjectOld.(*v1.Build)
-				newBuild := e.ObjectNew.(*v1.Build)
+				oldBuild, ok := e.ObjectOld.(*v1.Build)
+				if !ok {
+					return false
+				}
+				newBuild, ok := e.ObjectNew.(*v1.Build)
+				if !ok {
+					return false
+				}
 				// Ignore updates to the build CR except when the build phase changes
 				// as it's used to transition the integration kit from one phase
 				// to another during the image build
 				return oldBuild.Status.Phase != newBuild.Status.Phase
 			},
-		})
+		},
+	)
 	if err != nil {
 		return err
 	}
 
 	// Watch for IntegrationPlatform phase transitioning to ready and enqueue
-	// requests for any integrationkits that are in phase waiting for platform
-	err = c.Watch(&source.Kind{Type: &v1.IntegrationPlatform{}}, &handler.EnqueueRequestsFromMapFunc{
-		ToRequests: handler.ToRequestsFunc(func(a handler.MapObject) []reconcile.Request {
-			platform := a.Object.(*v1.IntegrationPlatform)
+	// requests for any integration kits that are in phase waiting for platform
+	err = c.Watch(&source.Kind{Type: &v1.IntegrationPlatform{}},
+		handler.EnqueueRequestsFromMapFunc(func(a ctrl.Object) []reconcile.Request {
 			var requests []reconcile.Request
+			p, ok := a.(*v1.IntegrationPlatform)
+			if !ok {
+				log.Error(fmt.Errorf("type assertion failed: %v", a), "Failed to list integration kits")
+				return requests
+			}
 
-			if platform.Status.Phase == v1.IntegrationPlatformPhaseReady {
+			if p.Status.Phase == v1.IntegrationPlatformPhaseReady {
 				list := &v1.IntegrationKitList{}
 
-				if err := mgr.GetClient().List(context.TODO(), list, k8sclient.InNamespace(platform.Namespace)); err != nil {
-					log.Error(err, "Failed to retrieve integrationkit list")
+				if err := mgr.GetClient().List(context.TODO(), list, ctrl.InNamespace(p.Namespace)); err != nil {
+					log.Error(err, "Failed to list integration kits")
 					return requests
 				}
 
 				for _, kit := range list.Items {
 					if kit.Status.Phase == v1.IntegrationKitPhaseWaitingForPlatform {
-						log.Infof("Platform %s ready, wake-up integrationkit: %s", platform.Name, kit.Name)
+						log.Infof("Platform %s ready, wake-up integration kit: %s", p.Name, kit.Name)
 						requests = append(requests, reconcile.Request{
 							NamespacedName: types.NamespacedName{
 								Namespace: kit.Namespace,
@@ -141,7 +168,7 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 
 			return requests
 		}),
-	})
+	)
 	if err != nil {
 		return err
 	}
@@ -149,12 +176,12 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 	return nil
 }
 
-var _ reconcile.Reconciler = &ReconcileIntegrationKit{}
+var _ reconcile.Reconciler = &reconcileIntegrationKit{}
 
-// ReconcileIntegrationKit reconciles a IntegrationKit object
-type ReconcileIntegrationKit struct {
+// reconcileIntegrationKit reconciles a IntegrationKit object
+type reconcileIntegrationKit struct {
 	// This client, initialized using mgr.Client() above, is a split client
-	// that reads objects from the cache and writes to the apiserver
+	// that reads objects from the cache and writes to the API server
 	client   client.Client
 	scheme   *runtime.Scheme
 	recorder record.EventRecorder
@@ -165,11 +192,17 @@ type ReconcileIntegrationKit struct {
 // Note:
 // The Controller will requeue the Request to be processed again if the returned error is non-nil or
 // Result.Requeue is true, otherwise upon completion it will remove the work from the queue.
-func (r *ReconcileIntegrationKit) Reconcile(request reconcile.Request) (reconcile.Result, error) {
+func (r *reconcileIntegrationKit) Reconcile(ctx context.Context, request reconcile.Request) (reconcile.Result, error) {
 	rlog := Log.WithValues("request-namespace", request.Namespace, "request-name", request.Name)
 	rlog.Info("Reconciling IntegrationKit")
 
-	ctx := context.TODO()
+	// Make sure the operator is allowed to act on namespace
+	if ok, err := platform.IsOperatorAllowedOnNamespace(ctx, r.client, request.Namespace); err != nil {
+		return reconcile.Result{}, err
+	} else if !ok {
+		rlog.Info("Ignoring request because namespace is locked")
+		return reconcile.Result{}, nil
+	}
 
 	var instance v1.IntegrationKit
 
@@ -185,11 +218,23 @@ func (r *ReconcileIntegrationKit) Reconcile(request reconcile.Request) (reconcil
 		return reconcile.Result{}, err
 	}
 
+	// Only process resources assigned to the operator
+	if !platform.IsOperatorHandler(&instance) {
+		rlog.Info("Ignoring request because resource is not assigned to current operator")
+		return reconcile.Result{}, nil
+	}
+
 	target := instance.DeepCopy()
 	targetLog := rlog.ForIntegrationKit(target)
 
 	if target.Status.Phase == v1.IntegrationKitPhaseNone || target.Status.Phase == v1.IntegrationKitPhaseWaitingForPlatform {
-		pl, err := platform.GetOrLookupCurrent(ctx, r.client, target.Namespace, target.Status.Platform)
+		if target.Labels[v1.IntegrationKitTypeLabel] == v1.IntegrationKitTypeExternal {
+			target.Status.Phase = v1.IntegrationKitPhaseInitialization
+			return r.update(ctx, &instance, target)
+		}
+
+		// Platform is always local to the kit
+		pl, err := platform.GetOrFindLocalForResource(ctx, r.client, target, true)
 		if err != nil || pl.Status.Phase != v1.IntegrationPlatformPhaseReady {
 			target.Status.Phase = v1.IntegrationKitPhaseWaitingForPlatform
 		} else {
@@ -256,7 +301,7 @@ func (r *ReconcileIntegrationKit) Reconcile(request reconcile.Request) (reconcil
 	return reconcile.Result{}, nil
 }
 
-func (r *ReconcileIntegrationKit) update(ctx context.Context, base *v1.IntegrationKit, target *v1.IntegrationKit) (reconcile.Result, error) {
+func (r *reconcileIntegrationKit) update(ctx context.Context, base *v1.IntegrationKit, target *v1.IntegrationKit) (reconcile.Result, error) {
 	dgst, err := digest.ComputeForIntegrationKit(target)
 	if err != nil {
 		return reconcile.Result{}, err
@@ -264,7 +309,7 @@ func (r *ReconcileIntegrationKit) update(ctx context.Context, base *v1.Integrati
 
 	target.Status.Digest = dgst
 
-	err = r.client.Status().Patch(ctx, target, k8sclient.MergeFrom(base))
+	err = r.client.Status().Patch(ctx, target, ctrl.MergeFrom(base))
 
 	return reconcile.Result{}, err
 }
