@@ -31,7 +31,6 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/event"
 	"sigs.k8s.io/controller-runtime/pkg/handler"
 	"sigs.k8s.io/controller-runtime/pkg/manager"
-	"sigs.k8s.io/controller-runtime/pkg/predicate"
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 	"sigs.k8s.io/controller-runtime/pkg/source"
 
@@ -57,6 +56,7 @@ func newReconciler(mgr manager.Manager, c client.Client) reconcile.Reconciler {
 	return monitoring.NewInstrumentedReconciler(
 		&reconcileIntegrationPlatform{
 			client:   c,
+			reader:   mgr.GetAPIReader(),
 			scheme:   mgr.GetScheme(),
 			recorder: mgr.GetEventRecorderFor("camel-k-integration-platform-controller"),
 		},
@@ -79,10 +79,16 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 	// Watch for changes to primary resource IntegrationPlatform
 	err = c.Watch(&source.Kind{Type: &v1.IntegrationPlatform{}},
 		&handler.EnqueueRequestForObject{},
-		predicate.Funcs{
+		platform.FilteringFuncs{
 			UpdateFunc: func(e event.UpdateEvent) bool {
-				oldIntegrationPlatform := e.ObjectOld.(*v1.IntegrationPlatform)
-				newIntegrationPlatform := e.ObjectNew.(*v1.IntegrationPlatform)
+				oldIntegrationPlatform, ok := e.ObjectOld.(*v1.IntegrationPlatform)
+				if !ok {
+					return false
+				}
+				newIntegrationPlatform, ok := e.ObjectNew.(*v1.IntegrationPlatform)
+				if !ok {
+					return false
+				}
 				// Ignore updates to the integration platform status in which case metadata.Generation
 				// does not change, or except when the integration platform phase changes as it's used
 				// to transition from one phase to another
@@ -108,7 +114,9 @@ var _ reconcile.Reconciler = &reconcileIntegrationPlatform{}
 type reconcileIntegrationPlatform struct {
 	// This client, initialized using mgr.Client() above, is a split client
 	// that reads objects from the cache and writes to the API server
-	client   client.Client
+	client client.Client
+	// Non-caching client
+	reader   ctrl.Reader
 	scheme   *runtime.Scheme
 	recorder record.EventRecorder
 }
@@ -146,9 +154,15 @@ func (r *reconcileIntegrationPlatform) Reconcile(ctx context.Context, request re
 		return reconcile.Result{}, err
 	}
 
+	// Only process resources assigned to the operator
+	if !platform.IsOperatorHandler(&instance) {
+		rlog.Info("Ignoring request because resource is not assigned to current operator")
+		return reconcile.Result{}, nil
+	}
+
 	actions := []Action{
 		NewInitializeAction(),
-		NewWarmAction(),
+		NewWarmAction(r.reader),
 		NewCreateAction(),
 		NewMonitorAction(),
 	}
