@@ -32,6 +32,7 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/intstr"
+	"k8s.io/kubectl/pkg/cmd/set/env"
 
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 
@@ -56,6 +57,7 @@ type OperatorConfiguration struct {
 	Tolerations           []string
 	NodeSelectors         []string
 	ResourcesRequirements []string
+	EnvVars               []string
 }
 
 type OperatorHealthConfiguration struct {
@@ -117,6 +119,20 @@ func OperatorOrCollect(ctx context.Context, c client.Client, cfg OperatorConfigu
 			}
 		}
 
+		if cfg.EnvVars != nil {
+			if d, ok := o.(*appsv1.Deployment); ok {
+				if d.Labels["camel.apache.org/component"] == "operator" {
+					envVars, _, err := env.ParseEnv(cfg.EnvVars, nil)
+					if err != nil {
+						fmt.Println("Warning: could not parse environment variables!")
+					}
+					for i := 0; i < len(d.Spec.Template.Spec.Containers); i++ {
+						d.Spec.Template.Spec.Containers[i].Env = append(d.Spec.Template.Spec.Containers[i].Env, envVars...)
+					}
+				}
+			}
+		}
+
 		if cfg.NodeSelectors != nil {
 			if d, ok := o.(*appsv1.Deployment); ok {
 				if d.Labels["camel.apache.org/component"] == "operator" {
@@ -173,7 +189,7 @@ func OperatorOrCollect(ctx context.Context, c client.Client, cfg OperatorConfigu
 					o = &rbacv1.ClusterRoleBinding{
 						ObjectMeta: metav1.ObjectMeta{
 							Namespace: cfg.Namespace,
-							Name:      rb.Name,
+							Name:      fmt.Sprintf("%s-%s", rb.Name, cfg.Namespace),
 							Labels: map[string]string{
 								"app": "camel-k",
 							},
@@ -208,7 +224,7 @@ func OperatorOrCollect(ctx context.Context, c client.Client, cfg OperatorConfigu
 		if err := installOpenShiftRoles(ctx, c, cfg.Namespace, customizer, collection, force); err != nil {
 			return err
 		}
-		if err := installOpenShiftClusterRoleBinding(ctx, c, collection, cfg.Namespace); err != nil {
+		if err := installClusterRoleBinding(ctx, c, collection, cfg.Namespace, "camel-k-operator-console-openshift", "/rbac/openshift/operator-cluster-role-console-binding-openshift.yaml"); err != nil {
 			if k8serrors.IsForbidden(err) {
 				fmt.Println("Warning: the operator will not be able to manage ConsoleCLIDownload resources. Try installing the operator as cluster-admin.")
 			} else {
@@ -261,20 +277,18 @@ func OperatorOrCollect(ctx context.Context, c client.Client, cfg OperatorConfigu
 		fmt.Println("Warning: the operator will not be able to create Leases. Try installing as cluster-admin to allow management of Lease resources.")
 	}
 
-	if errmtr := installServiceBindings(ctx, c, cfg.Namespace, customizer, collection, force); errmtr != nil {
-		if k8serrors.IsAlreadyExists(errmtr) {
-			return errmtr
-		}
-		fmt.Println("Warning: the operator will not be able to lookup ServiceBinding resources. Try installing as cluster-admin to allow the lookup of ServiceBinding resources.")
+	if errmtr := installClusterRoleBinding(ctx, c, collection, cfg.Namespace, "camel-k-operator-custom-resource-definitions", "/rbac/operator-cluster-role-binding-custom-resource-definitions.yaml"); errmtr != nil {
+		fmt.Println("Warning: the operator will not be able to get CustomResourceDefinitions resources and the service-binding trait will fail if used. Try installing the operator as cluster-admin.")
 	}
 
 	if cfg.Monitoring.Enabled {
 		if err := installMonitoringResources(ctx, c, cfg.Namespace, customizer, collection, force); err != nil {
-			if k8serrors.IsForbidden(err) {
+			switch {
+			case k8serrors.IsForbidden(err):
 				fmt.Println("Warning: the creation of monitoring resources is not allowed. Try installing as cluster-admin to allow the creation of monitoring resources.")
-			} else if meta.IsNoMatchError(errors.Cause(err)) {
+			case meta.IsNoMatchError(errors.Cause(err)):
 				fmt.Println("Warning: the creation of the monitoring resources failed: ", err)
-			} else {
+			default:
 				return err
 			}
 		}
@@ -283,19 +297,25 @@ func OperatorOrCollect(ctx context.Context, c client.Client, cfg OperatorConfigu
 	return nil
 }
 
-func installOpenShiftClusterRoleBinding(ctx context.Context, c client.Client, collection *kubernetes.Collection, namespace string) error {
+func installClusterRoleBinding(ctx context.Context, c client.Client, collection *kubernetes.Collection, namespace string, name string, path string) error {
 	var target *rbacv1.ClusterRoleBinding
-	existing, err := c.RbacV1().ClusterRoleBindings().Get(ctx, "camel-k-operator-openshift", metav1.GetOptions{})
-	if k8serrors.IsNotFound(err) {
+	existing, err := c.RbacV1().ClusterRoleBindings().Get(ctx, name, metav1.GetOptions{})
+	switch {
+	case k8serrors.IsNotFound(err):
 		existing = nil
-		obj, err := kubernetes.LoadResourceFromYaml(c.GetScheme(), resources.ResourceAsString("/rbac/operator-cluster-role-binding-openshift.yaml"))
+		yaml := resources.ResourceAsString(path)
+		if yaml == "" {
+			return errors.Errorf("resource file %v not found", path)
+		}
+		obj, err := kubernetes.LoadResourceFromYaml(c.GetScheme(), yaml)
 		if err != nil {
 			return err
 		}
+		// nolint: forcetypeassert
 		target = obj.(*rbacv1.ClusterRoleBinding)
-	} else if err != nil {
+	case err != nil:
 		return err
-	} else {
+	default:
 		target = existing.DeepCopy()
 	}
 
@@ -304,10 +324,12 @@ func installOpenShiftClusterRoleBinding(ctx context.Context, c client.Client, co
 		if subject.Name == "camel-k-operator" {
 			if subject.Namespace == namespace {
 				bound = true
+
 				break
 			} else if subject.Namespace == "" {
 				target.Subjects[i].Namespace = namespace
 				bound = true
+
 				break
 			}
 		}
@@ -328,32 +350,33 @@ func installOpenShiftClusterRoleBinding(ctx context.Context, c client.Client, co
 
 	if existing == nil {
 		return c.Create(ctx, target)
-	} else {
-		// The ClusterRoleBinding.Subjects field does not have a patchStrategy key in its field tag,
-		// so a strategic merge patch would use the default patch strategy, which is replace.
-		// Let's compute a simple JSON merge patch from the existing resource, and patch it.
-		p, err := patch.PositiveMergePatch(existing, target)
-		if err != nil {
-			return err
-		} else if len(p) == 0 {
-			// Avoid triggering a patch request for nothing
-			return nil
-		}
-		return c.Patch(ctx, existing, ctrl.RawPatch(types.MergePatchType, p))
 	}
+
+	// The ClusterRoleBinding.Subjects field does not have a patchStrategy key in its field tag,
+	// so a strategic merge patch would use the default patch strategy, which is replace.
+	// Let's compute a simple JSON merge patch from the existing resource, and patch it.
+	p, err := patch.PositiveMergePatch(existing, target)
+	if err != nil {
+		return err
+	} else if len(p) == 0 {
+		// Avoid triggering a patch request for nothing
+		return nil
+	}
+
+	return c.Patch(ctx, existing, ctrl.RawPatch(types.MergePatchType, p))
 }
 
 func installOpenShiftRoles(ctx context.Context, c client.Client, namespace string, customizer ResourceCustomizer, collection *kubernetes.Collection, force bool) error {
 	return ResourcesOrCollect(ctx, c, namespace, collection, force, customizer,
-		"/rbac/operator-role-openshift.yaml",
-		"/rbac/operator-role-binding-openshift.yaml",
+		"/rbac/openshift/operator-role-openshift.yaml",
+		"/rbac/openshift/operator-role-binding-openshift.yaml",
 	)
 }
 
 func installKubernetesRoles(ctx context.Context, c client.Client, namespace string, customizer ResourceCustomizer, collection *kubernetes.Collection, force bool) error {
 	return ResourcesOrCollect(ctx, c, namespace, collection, force, customizer,
 		"/manager/operator-service-account.yaml",
-		"/rbac/operator-role-kubernetes.yaml",
+		"/rbac/operator-role.yaml",
 		"/rbac/operator-role-binding.yaml",
 	)
 }
@@ -406,16 +429,9 @@ func installLeaseBindings(ctx context.Context, c client.Client, namespace string
 	)
 }
 
-func installServiceBindings(ctx context.Context, c client.Client, namespace string, customizer ResourceCustomizer, collection *kubernetes.Collection, force bool) error {
-	return ResourcesOrCollect(ctx, c, namespace, collection, force, customizer,
-		"/rbac/operator-role-service-binding.yaml",
-		"/rbac/operator-role-binding-service-binding.yaml",
-	)
-}
-
 // PlatformOrCollect --
 // nolint: lll
-func PlatformOrCollect(ctx context.Context, c client.Client, clusterType string, namespace string, skipRegistrySetup bool, registry v1.IntegrationPlatformRegistrySpec, collection *kubernetes.Collection) (*v1.IntegrationPlatform, error) {
+func PlatformOrCollect(ctx context.Context, c client.Client, clusterType string, namespace string, skipRegistrySetup bool, registry v1.RegistrySpec, collection *kubernetes.Collection) (*v1.IntegrationPlatform, error) {
 	isOpenShift, err := isOpenShift(c, clusterType)
 	if err != nil {
 		return nil, err
@@ -424,13 +440,18 @@ func PlatformOrCollect(ctx context.Context, c client.Client, clusterType string,
 	if err != nil {
 		return nil, err
 	}
-	pl := platformObject.(*v1.IntegrationPlatform)
+	pl, ok := platformObject.(*v1.IntegrationPlatform)
+	if !ok {
+		return nil, fmt.Errorf("type assertion failed: %v", platformObject)
+	}
 
-	if !isOpenShift && !skipRegistrySetup {
+	if !skipRegistrySetup {
+		// Let's apply registry settings whether it's OpenShift or not
+		// Some OpenShift variants such as Microshift might not have a built-in registry
 		pl.Spec.Build.Registry = registry
 
 		// Kubernetes only (Minikube)
-		if registry.Address == "" {
+		if !isOpenShift && registry.Address == "" {
 			// This operation should be done here in the installer
 			// because the operator is not allowed to look into the "kube-system" namespace
 			address, err := minikube.FindRegistry(ctx, c)
