@@ -21,30 +21,20 @@ import (
 	"context"
 	"strings"
 
-	"github.com/apache/camel-k/pkg/client"
+	"github.com/apache/camel-k/pkg/util/defaults"
 	"github.com/go-logr/logr"
+
+	"github.com/apache/camel-k/pkg/client"
 )
 
 // OperatorStartupOptionalTools tries to install optional tools at operator startup and warns if something goes wrong
 func OperatorStartupOptionalTools(ctx context.Context, c client.Client, namespace string, operatorNamespace string, log logr.Logger) {
-
 	// Try to register the OpenShift CLI Download link if possible
 	if err := OpenShiftConsoleDownloadLink(ctx, c); err != nil {
 		log.Info("Cannot install OpenShift CLI download link: skipping.")
 		log.V(8).Info("Error while installing OpenShift CLI download link", "error", err)
 	}
 
-	// Try to register the cluster role for standard admin and edit users
-	if clusterRoleInstalled, err := IsClusterRoleInstalled(ctx, c); err != nil {
-		log.Info("Cannot detect user cluster role: skipping.")
-		log.V(8).Info("Error while getting user cluster role", "error", err)
-	} else if !clusterRoleInstalled {
-		if err := installClusterRole(ctx, c, nil); err != nil {
-			log.Info("Cannot install user cluster role: skipping.")
-			log.V(8).Info("Error while installing user cluster role", "error", err)
-		}
-	}
-
 	// Try to install Kamelet Catalog automatically
 	var kameletNamespace string
 	globalOperator := false
@@ -56,9 +46,13 @@ func OperatorStartupOptionalTools(ctx context.Context, c client.Client, namespac
 	}
 
 	if kameletNamespace != "" {
-		if err := KameletCatalog(ctx, c, kameletNamespace); err != nil {
-			log.Info("Cannot install bundled Kamelet Catalog: skipping.")
-			log.V(8).Info("Error while installing bundled Kamelet Catalog", "error", err)
+		if defaults.InstallDefaultKamelets() {
+			if err := KameletCatalog(ctx, c, kameletNamespace); err != nil {
+				log.Info("Cannot install bundled Kamelet Catalog: skipping.")
+				log.V(8).Info("Error while installing bundled Kamelet Catalog", "error", err)
+			}
+		} else {
+			log.Info("Kamelet Catalog installation is disabled")
 		}
 
 		if globalOperator {
@@ -69,5 +63,4 @@ func OperatorStartupOptionalTools(ctx context.Context, c client.Client, namespac
 			}
 		}
 	}
-
 }
