@@ -21,12 +21,12 @@ import (
 	"fmt"
 	"sort"
 
-	"github.com/apache/camel-k/pkg/util/property"
 	corev1 "k8s.io/api/core/v1"
 
 	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/pkg/builder"
 	mvn "github.com/apache/camel-k/pkg/util/maven"
+	"github.com/apache/camel-k/pkg/util/property"
 )
 
 // The builder trait is internally used to determine the best strategy to
@@ -58,7 +58,7 @@ func (t *builderTrait) InfluencesKit() bool {
 }
 
 func (t *builderTrait) Configure(e *Environment) (bool, error) {
-	if t.Enabled != nil && !*t.Enabled {
+	if IsFalse(t.Enabled) {
 		return false, nil
 	}
 
@@ -71,7 +71,7 @@ func (t *builderTrait) Apply(e *Environment) error {
 		e.IntegrationKit.Status.Phase = v1.IntegrationKitPhaseError
 		e.IntegrationKit.Status.SetCondition("IntegrationKitPropertiesFormatValid", corev1.ConditionFalse,
 			"IntegrationKitPropertiesFormatValid", fmt.Sprintf("One or more properties where not formatted as expected: %s", err.Error()))
-		if err := e.Client.Status().Update(e.C, e.IntegrationKit); err != nil {
+		if err := e.Client.Status().Update(e.Ctx, e.IntegrationKit); err != nil {
 			return err
 		}
 		return nil
@@ -137,7 +137,7 @@ func (t *builderTrait) Apply(e *Environment) error {
 func (t *builderTrait) builderTask(e *Environment) (*v1.BuilderTask, error) {
 	maven := e.Platform.Status.Build.Maven
 
-	// Add Maven repositories defined in the IntergrationKit
+	// Add Maven repositories defined in the IntegrationKit
 	for _, repo := range e.IntegrationKit.Spec.Repositories {
 		maven.Repositories = append(maven.Repositories, mvn.NewRepository(repo))
 	}
@@ -145,6 +145,7 @@ func (t *builderTrait) builderTask(e *Environment) (*v1.BuilderTask, error) {
 		BaseTask: v1.BaseTask{
 			Name: "builder",
 		},
+		BaseImage:    e.Platform.Status.Build.BaseImage,
 		Runtime:      e.CamelCatalog.Runtime,
 		Dependencies: e.IntegrationKit.Spec.Dependencies,
 		Maven:        maven,
@@ -166,10 +167,7 @@ func (t *builderTrait) builderTask(e *Environment) (*v1.BuilderTask, error) {
 	}
 
 	steps := make([]builder.Step, 0)
-	steps = append(steps, builder.DefaultSteps...)
-
-	quarkus := e.Catalog.GetTrait("quarkus").(*quarkusTrait)
-	quarkus.addBuildSteps(&steps)
+	steps = append(steps, builder.Project.CommonSteps...)
 
 	// sort steps by phase
 	sort.SliceStable(steps, func(i, j int) bool {
