@@ -24,7 +24,7 @@ import (
 	"strings"
 
 	batchv1 "k8s.io/api/batch/v1"
-	"k8s.io/api/batch/v1beta1"
+	batchv1beta1 "k8s.io/api/batch/v1beta1"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
@@ -32,6 +32,7 @@ import (
 	"github.com/apache/camel-k/pkg/metadata"
 	"github.com/apache/camel-k/pkg/util"
 	"github.com/apache/camel-k/pkg/util/kubernetes"
+	"github.com/apache/camel-k/pkg/util/label"
 	"github.com/apache/camel-k/pkg/util/uri"
 )
 
@@ -79,6 +80,13 @@ type cronTrait struct {
 	// Optional deadline in seconds for starting the job if it misses scheduled
 	// time for any reason.  Missed jobs executions will be counted as failed ones.
 	StartingDeadlineSeconds *int64 `property:"starting-deadline-seconds" json:"startingDeadlineSeconds,omitempty"`
+	// Specifies the duration in seconds, relative to the start time, that the job
+	// may be continuously active before it is considered to be failed.
+	// It defaults to 60s.
+	ActiveDeadlineSeconds *int64 `property:"active-deadline-seconds" json:"activeDeadlineSeconds,omitempty"`
+	// Specifies the number of retries before marking the job failed.
+	// It defaults to 2.
+	BackoffLimit *int32 `property:"backoff-limit" json:"backoffLimit,omitempty"`
 }
 
 var _ ControllerStrategySelector = &cronTrait{}
@@ -164,7 +172,7 @@ func (t *cronTrait) Configure(e *Environment) (bool, error) {
 		}
 
 		if t.ConcurrencyPolicy == "" {
-			t.ConcurrencyPolicy = string(v1beta1.ForbidConcurrent)
+			t.ConcurrencyPolicy = string(batchv1beta1.ForbidConcurrent)
 		}
 
 		if (t.Schedule == "" && t.Components == "") && t.Fallback == nil {
@@ -244,9 +252,6 @@ func (t *cronTrait) Apply(e *Environment) error {
 		e.Interceptors = append(e.Interceptors, "cron")
 
 		cronJob := t.getCronJobFor(e)
-		maps := e.computeConfigMaps()
-
-		e.Resources.AddAll(maps)
 		e.Resources.Add(cronJob)
 
 		e.Integration.Status.SetCondition(
@@ -259,8 +264,7 @@ func (t *cronTrait) Apply(e *Environment) error {
 	return nil
 }
 
-func (t *cronTrait) getCronJobFor(e *Environment) *v1beta1.CronJob {
-	// Copy annotations from the integration resource
+func (t *cronTrait) getCronJobFor(e *Environment) *batchv1beta1.CronJob {
 	annotations := make(map[string]string)
 	if e.Integration.Annotations != nil {
 		for k, v := range filterTransferableAnnotations(e.Integration.Annotations) {
@@ -268,10 +272,20 @@ func (t *cronTrait) getCronJobFor(e *Environment) *v1beta1.CronJob {
 		}
 	}
 
-	cronjob := v1beta1.CronJob{
+	activeDeadline := int64(60)
+	if t.ActiveDeadlineSeconds != nil {
+		activeDeadline = *t.ActiveDeadlineSeconds
+	}
+
+	backoffLimit := int32(2)
+	if t.BackoffLimit != nil {
+		backoffLimit = *t.BackoffLimit
+	}
+
+	cronjob := batchv1beta1.CronJob{
 		TypeMeta: metav1.TypeMeta{
 			Kind:       "CronJob",
-			APIVersion: v1beta1.SchemeGroupVersion.String(),
+			APIVersion: batchv1beta1.SchemeGroupVersion.String(),
 		},
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      e.Integration.Name,
@@ -281,17 +295,17 @@ func (t *cronTrait) getCronJobFor(e *Environment) *v1beta1.CronJob {
 			},
 			Annotations: e.Integration.Annotations,
 		},
-		Spec: v1beta1.CronJobSpec{
+		Spec: batchv1beta1.CronJobSpec{
 			Schedule:                t.Schedule,
-			ConcurrencyPolicy:       v1beta1.ConcurrencyPolicy(t.ConcurrencyPolicy),
+			ConcurrencyPolicy:       batchv1beta1.ConcurrencyPolicy(t.ConcurrencyPolicy),
 			StartingDeadlineSeconds: t.StartingDeadlineSeconds,
-			JobTemplate: v1beta1.JobTemplateSpec{
+			JobTemplate: batchv1beta1.JobTemplateSpec{
 				Spec: batchv1.JobSpec{
+					ActiveDeadlineSeconds: &activeDeadline,
+					BackoffLimit:          &backoffLimit,
 					Template: corev1.PodTemplateSpec{
 						ObjectMeta: metav1.ObjectMeta{
-							Labels: map[string]string{
-								v1.IntegrationLabel: e.Integration.Name,
-							},
+							Labels:      label.AddLabels(e.Integration.Name),
 							Annotations: annotations,
 						},
 						Spec: corev1.PodSpec{
@@ -381,7 +395,7 @@ func (t *cronTrait) getGlobalCron(e *Environment) (*cronInfo, error) {
 func (t *cronTrait) getSourcesFromURIs(e *Environment) ([]string, error) {
 	var sources []v1.SourceSpec
 	var err error
-	if sources, err = kubernetes.ResolveIntegrationSources(t.Ctx, t.Client, e.Integration, e.Resources); err != nil {
+	if sources, err = kubernetes.ResolveIntegrationSources(e.Ctx, t.Client, e.Integration, e.Resources); err != nil {
 		return nil, err
 	}
 	meta := metadata.ExtractAll(e.CamelCatalog, sources)
@@ -415,7 +429,7 @@ func getCronForURI(camelURI string) *cronInfo {
 // Specific extractors
 
 // timerToCronInfo converts a timer endpoint to a Kubernetes cron schedule
-// nolint: gocritic
+
 func timerToCronInfo(camelURI string) *cronInfo {
 	if uri.GetQueryParameter(camelURI, "delay") != "" ||
 		uri.GetQueryParameter(camelURI, "repeatCount") != "" ||
