@@ -25,6 +25,7 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
 	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/pkg/util/label"
 )
 
 // The Deployment trait is responsible for generating the Kubernetes deployment that will make sure
@@ -33,6 +34,9 @@ import (
 // +camel-k:trait=deployment
 type deploymentTrait struct {
 	BaseTrait `property:",squash"`
+	// The maximum time in seconds for the deployment to make progress before it
+	// is considered to be failed. It defaults to 60s.
+	ProgressDeadlineSeconds *int32 `property:"progress-deadline-seconds" json:"progressDeadlineSeconds,omitempty"`
 }
 
 var _ ControllerStrategySelector = &deploymentTrait{}
@@ -98,10 +102,7 @@ func (t *deploymentTrait) ControllerStrategySelectorOrder() int {
 }
 
 func (t *deploymentTrait) Apply(e *Environment) error {
-	maps := e.computeConfigMaps()
 	deployment := t.getDeploymentFor(e)
-
-	e.Resources.AddAll(maps)
 	e.Resources.Add(deployment)
 
 	e.Integration.Status.SetCondition(
@@ -128,6 +129,11 @@ func (t *deploymentTrait) getDeploymentFor(e *Environment) *appsv1.Deployment {
 		}
 	}
 
+	deadline := int32(60)
+	if t.ProgressDeadlineSeconds != nil {
+		deadline = *t.ProgressDeadlineSeconds
+	}
+
 	deployment := appsv1.Deployment{
 		TypeMeta: metav1.TypeMeta{
 			Kind:       "Deployment",
@@ -142,7 +148,8 @@ func (t *deploymentTrait) getDeploymentFor(e *Environment) *appsv1.Deployment {
 			Annotations: annotations,
 		},
 		Spec: appsv1.DeploymentSpec{
-			Replicas: e.Integration.Spec.Replicas,
+			ProgressDeadlineSeconds: &deadline,
+			Replicas:                e.Integration.Spec.Replicas,
 			Selector: &metav1.LabelSelector{
 				MatchLabels: map[string]string{
 					v1.IntegrationLabel: e.Integration.Name,
@@ -150,9 +157,7 @@ func (t *deploymentTrait) getDeploymentFor(e *Environment) *appsv1.Deployment {
 			},
 			Template: corev1.PodTemplateSpec{
 				ObjectMeta: metav1.ObjectMeta{
-					Labels: map[string]string{
-						v1.IntegrationLabel: e.Integration.Name,
-					},
+					Labels:      label.AddLabels(e.Integration.Name),
 					Annotations: annotations,
 				},
 				Spec: corev1.PodSpec{
