@@ -71,8 +71,18 @@ func (t *jvmTrait) Configure(e *Environment) (bool, error) {
 		return false, nil
 	}
 
-	return e.InPhase(v1.IntegrationKitPhaseReady, v1.IntegrationPhaseDeploying) ||
-		e.InPhase(v1.IntegrationKitPhaseReady, v1.IntegrationPhaseRunning), nil
+	if !e.IntegrationKitInPhase(v1.IntegrationKitPhaseReady) || !e.IntegrationInRunningPhases() {
+		return false, nil
+	}
+
+	if trait := e.Catalog.GetTrait(quarkusTraitID); trait != nil {
+		// The JVM trait must be disabled in case the current IntegrationKit corresponds to a native build
+		if quarkus, ok := trait.(*quarkusTrait); ok && IsNilOrTrue(quarkus.Enabled) && quarkus.isNativeIntegration(e) {
+			return false, nil
+		}
+	}
+
+	return true, nil
 }
 
 func (t *jvmTrait) Apply(e *Environment) error {
@@ -82,10 +92,10 @@ func (t *jvmTrait) Apply(e *Environment) error {
 		name := e.Integration.Status.IntegrationKit.Name
 		ns := e.Integration.GetIntegrationKitNamespace(e.Platform)
 		k := v1.NewIntegrationKit(ns, name)
-		if err := t.Client.Get(t.Ctx, ctrl.ObjectKeyFromObject(&k), &k); err != nil {
+		if err := t.Client.Get(e.Ctx, ctrl.ObjectKeyFromObject(k), k); err != nil {
 			return errors.Wrapf(err, "unable to find integration kit %s/%s, %s", ns, name, err)
 		}
-		kit = &k
+		kit = k
 	}
 
 	if kit == nil {
@@ -108,10 +118,10 @@ func (t *jvmTrait) Apply(e *Environment) error {
 		classpath.Add(artifact.Target)
 	}
 
-	if kit.Labels["camel.apache.org/kit.type"] == v1.IntegrationKitTypeExternal {
+	if kit.Labels[v1.IntegrationKitTypeLabel] == v1.IntegrationKitTypeExternal {
 		// In case of an external created kit, we do not have any information about
-		// the classpath so we assume the all jars in /deployments/dependencies/ have
-		// to be taken into account
+		// the classpath, so we assume the all jars in /deployments/dependencies/ have
+		// to be taken into account.
 		dependencies := path.Join(builder.DeploymentDir, builder.DependenciesDir)
 		classpath.Add(
 			dependencies+"/*",
@@ -122,7 +132,7 @@ func (t *jvmTrait) Apply(e *Environment) error {
 		)
 	}
 
-	container := e.getIntegrationContainer()
+	container := e.GetIntegrationContainer()
 	if container == nil {
 		return nil
 	}
