@@ -18,7 +18,6 @@ limitations under the License.
 package trait
 
 import (
-	"context"
 	"fmt"
 	"sort"
 	"strings"
@@ -54,7 +53,7 @@ func TestConfigureJvmTraitInWrongIntegrationPhaseDoesNotSucceed(t *testing.T) {
 
 	configured, err := trait.Configure(environment)
 	assert.Nil(t, err)
-	assert.False(t, configured)
+	assert.True(t, configured)
 }
 
 func TestConfigureJvmTraitInWrongIntegrationKitPhaseDoesNotSucceed(t *testing.T) {
@@ -202,7 +201,7 @@ func TestApplyJvmTraitWithExternalKitType(t *testing.T) {
 	err := trait.Apply(environment)
 	assert.Nil(t, err)
 
-	container := environment.getIntegrationContainer()
+	container := environment.GetIntegrationContainer()
 
 	assert.Equal(t, 3, len(container.Args))
 	assert.Equal(t, "-cp", container.Args[0])
@@ -255,14 +254,13 @@ func createNominalJvmTest(kitType string) (*jvmTrait, *Environment) {
 
 	client, _ := test.NewFakeClient()
 
-	trait := newJvmTrait().(*jvmTrait)
+	trait, _ := newJvmTrait().(*jvmTrait)
 	trait.Enabled = BoolP(true)
 	trait.PrintCommand = BoolP(false)
-	trait.Ctx = context.TODO()
 	trait.Client = client
 
 	environment := &Environment{
-		Catalog:      NewCatalog(context.TODO(), nil),
+		Catalog:      NewCatalog(nil),
 		CamelCatalog: catalog,
 		Integration: &v1.Integration{
 			Status: v1.IntegrationStatus{
@@ -278,7 +276,7 @@ func createNominalJvmTest(kitType string) (*jvmTrait, *Environment) {
 				Namespace: "kit-namespace",
 				Name:      "kit-name",
 				Labels: map[string]string{
-					"camel.apache.org/kit.type": kitType,
+					v1.IntegrationKitTypeLabel: kitType,
 				},
 			},
 			Status: v1.IntegrationKitStatus{
