@@ -29,21 +29,27 @@ import (
 	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/pkg/metadata"
 	"github.com/apache/camel-k/pkg/util/kubernetes"
+	"github.com/apache/camel-k/pkg/util/label"
 )
 
 const (
+	knativeServiceTraitID = "knative-service"
+
+	// Auto-scaling annotations
 	knativeServingClassAnnotation    = "autoscaling.knative.dev/class"
 	knativeServingMetricAnnotation   = "autoscaling.knative.dev/metric"
 	knativeServingTargetAnnotation   = "autoscaling.knative.dev/target"
 	knativeServingMinScaleAnnotation = "autoscaling.knative.dev/minScale"
 	knativeServingMaxScaleAnnotation = "autoscaling.knative.dev/maxScale"
+	// Rollout annotation
+	knativeServingRolloutDurationAnnotation = "serving.knative.dev/rolloutDuration"
 )
 
-// The Knative Service trait allows to configure options when running the integration as Knative service instead of
+// The Knative Service trait allows configuring options when running the Integration as a Knative service, instead of
 // a standard Kubernetes Deployment.
 //
-// Running integrations as Knative Services adds auto-scaling (and scaling-to-zero) features, but those features
-// are only meaningful when the routes use a HTTP endpoint consumer.
+// Running an Integration as a Knative Service enables auto-scaling (and scaling-to-zero), but those features
+// are only relevant when the Camel route(s) use(s) an HTTP endpoint consumer.
 //
 // +camel-k:trait=knative-service
 type knativeServiceTrait struct {
@@ -70,6 +76,10 @@ type knativeServiceTrait struct {
 	//
 	// Refer to the Knative documentation for more information.
 	MaxScale *int `property:"max-scale" json:"maxScale,omitempty"`
+	// Enables to gradually shift traffic to the latest Revision and sets the rollout duration.
+	// It's disabled by default and must be expressed as a Golang `time.Duration` string representation,
+	// rounded to a second precision.
+	RolloutDuration string `property:"rollout-duration" json:"rolloutDuration,omitempty"`
 	// Automatically deploy the integration as Knative service when all conditions hold:
 	//
 	// * Integration is using the Knative profile
@@ -81,7 +91,7 @@ var _ ControllerStrategySelector = &knativeServiceTrait{}
 
 func newKnativeServiceTrait() Trait {
 	return &knativeServiceTrait{
-		BaseTrait: NewBaseTrait("knative-service", 1400),
+		BaseTrait: NewBaseTrait(knativeServiceTraitID, 1400),
 	}
 }
 
@@ -142,7 +152,7 @@ func (t *knativeServiceTrait) Configure(e *Environment) (bool, error) {
 	if IsNilOrTrue(t.Auto) {
 		// Check the right value for minScale, as not all services are allowed to scale down to 0
 		if t.MinScale == nil {
-			sources, err := kubernetes.ResolveIntegrationSources(t.Ctx, t.Client, e.Integration, e.Resources)
+			sources, err := kubernetes.ResolveIntegrationSources(e.Ctx, t.Client, e.Integration, e.Resources)
 			if err != nil {
 				e.Integration.Status.SetErrorCondition(
 					v1.IntegrationConditionKnativeServiceAvailable,
@@ -174,9 +184,6 @@ func (t *knativeServiceTrait) Apply(e *Environment) error {
 	if err != nil {
 		return err
 	}
-	maps := e.computeConfigMaps()
-
-	e.Resources.AddAll(maps)
 	e.Resources.Add(ksvc)
 
 	e.Integration.Status.SetCondition(
@@ -200,7 +207,7 @@ func (t *knativeServiceTrait) SelectControllerStrategy(e *Environment) (*Control
 
 	var sources []v1.SourceSpec
 	var err error
-	if sources, err = kubernetes.ResolveIntegrationSources(t.Ctx, t.Client, e.Integration, e.Resources); err != nil {
+	if sources, err = kubernetes.ResolveIntegrationSources(e.Ctx, t.Client, e.Integration, e.Resources); err != nil {
 		return nil, err
 	}
 
@@ -216,29 +223,38 @@ func (t *knativeServiceTrait) ControllerStrategySelectorOrder() int {
 }
 
 func (t *knativeServiceTrait) getServiceFor(e *Environment) (*serving.Service, error) {
-	// Copy annotations from the integration resource
-	annotations := make(map[string]string)
+	serviceAnnotations := make(map[string]string)
 	if e.Integration.Annotations != nil {
-		for k, v := range filterTransferableAnnotations(e.Integration.Annotations) {
-			annotations[k] = v
+		for k, v := range e.Integration.Annotations {
+			serviceAnnotations[k] = v
 		}
 	}
+	// Set Knative rollout
+	if t.RolloutDuration != "" {
+		serviceAnnotations[knativeServingRolloutDurationAnnotation] = t.RolloutDuration
+	}
 
-	// Set Knative auto-scaling behavior
+	revisionAnnotations := make(map[string]string)
+	if e.Integration.Annotations != nil {
+		for k, v := range filterTransferableAnnotations(e.Integration.Annotations) {
+			revisionAnnotations[k] = v
+		}
+	}
+	// Set Knative auto-scaling
 	if t.Class != "" {
-		annotations[knativeServingClassAnnotation] = t.Class
+		revisionAnnotations[knativeServingClassAnnotation] = t.Class
 	}
 	if t.Metric != "" {
-		annotations[knativeServingMetricAnnotation] = t.Metric
+		revisionAnnotations[knativeServingMetricAnnotation] = t.Metric
 	}
 	if t.Target != nil {
-		annotations[knativeServingTargetAnnotation] = strconv.Itoa(*t.Target)
+		revisionAnnotations[knativeServingTargetAnnotation] = strconv.Itoa(*t.Target)
 	}
 	if t.MinScale != nil && *t.MinScale > 0 {
-		annotations[knativeServingMinScaleAnnotation] = strconv.Itoa(*t.MinScale)
+		revisionAnnotations[knativeServingMinScaleAnnotation] = strconv.Itoa(*t.MinScale)
 	}
 	if t.MaxScale != nil && *t.MaxScale > 0 {
-		annotations[knativeServingMaxScaleAnnotation] = strconv.Itoa(*t.MaxScale)
+		revisionAnnotations[knativeServingMaxScaleAnnotation] = strconv.Itoa(*t.MaxScale)
 	}
 
 	svc := serving.Service{
@@ -252,16 +268,14 @@ func (t *knativeServiceTrait) getServiceFor(e *Environment) (*serving.Service, e
 			Labels: map[string]string{
 				v1.IntegrationLabel: e.Integration.Name,
 			},
-			Annotations: e.Integration.Annotations,
+			Annotations: serviceAnnotations,
 		},
 		Spec: serving.ServiceSpec{
 			ConfigurationSpec: serving.ConfigurationSpec{
 				Template: serving.RevisionTemplateSpec{
 					ObjectMeta: metav1.ObjectMeta{
-						Labels: map[string]string{
-							v1.IntegrationLabel: e.Integration.Name,
-						},
-						Annotations: annotations,
+						Labels:      label.AddLabels(e.Integration.Name),
+						Annotations: revisionAnnotations,
 					},
 					Spec: serving.RevisionSpec{
 						PodSpec: corev1.PodSpec{
