@@ -20,24 +20,25 @@ package trait
 import (
 	"context"
 
+	"github.com/pkg/errors"
+
 	corev1 "k8s.io/api/core/v1"
+	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 
 	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/pkg/client"
 	"github.com/apache/camel-k/pkg/platform"
 	"github.com/apache/camel-k/pkg/util/kubernetes"
-	"github.com/pkg/errors"
-	k8serrors "k8s.io/apimachinery/pkg/api/errors"
+	k8sclient "sigs.k8s.io/controller-runtime/pkg/client"
 )
 
-// Apply --
 func Apply(ctx context.Context, c client.Client, integration *v1.Integration, kit *v1.IntegrationKit) (*Environment, error) {
 	environment, err := newEnvironment(ctx, c, integration, kit)
 	if err != nil {
 		return nil, err
 	}
 
-	catalog := NewCatalog(ctx, c)
+	catalog := NewCatalog(c)
 
 	// set the catalog
 	environment.Catalog = catalog
@@ -64,27 +65,27 @@ func newEnvironment(ctx context.Context, c client.Client, integration *v1.Integr
 		return nil, errors.New("neither integration nor kit are set")
 	}
 
-	namespace := ""
+	var obj k8sclient.Object
 	if integration != nil {
-		namespace = integration.Namespace
+		obj = integration
 	} else if kit != nil {
-		namespace = kit.Namespace
+		obj = kit
 	}
 
-	pl, err := platform.GetCurrentPlatform(ctx, c, namespace)
+	pl, err := platform.GetForResource(ctx, c, obj)
 	if err != nil && !k8serrors.IsNotFound(err) {
 		return nil, err
 	}
 
 	if kit == nil {
-		kit, err = GetIntegrationKit(ctx, c, integration)
+		kit, err = getIntegrationKit(ctx, c, integration)
 		if err != nil {
 			return nil, err
 		}
 	}
 
 	env := Environment{
-		C:                     ctx,
+		Ctx:                   ctx,
 		Platform:              pl,
 		Client:                c,
 		IntegrationKit:        kit,
