@@ -20,33 +20,38 @@ package trait
 func init() {
 	// List of default trait factories.
 	// Declaration order is not important, but let's keep them sorted for debugging.
-	AddToTraits(newInitTrait)
-	AddToTraits(newPlatformTrait)
-	AddToTraits(newCamelTrait)
-	AddToTraits(newOpenAPITrait)
-	AddToTraits(newKnativeTrait)
-	AddToTraits(newKameletsTrait)
-	AddToTraits(newDependenciesTrait)
-	AddToTraits(newBuilderTrait)
-	AddToTraits(newQuarkusTrait)
-	AddToTraits(newEnvironmentTrait)
-	AddToTraits(newDeployerTrait)
-	AddToTraits(newCronTrait)
-	AddToTraits(newDeploymentTrait)
-	AddToTraits(newGarbageCollectorTrait)
 	AddToTraits(newAffinityTrait)
-	AddToTraits(newTolerationTrait)
-	AddToTraits(newKnativeServiceTrait)
-	AddToTraits(newServiceTrait)
+	AddToTraits(newBuilderTrait)
+	AddToTraits(newCamelTrait)
 	AddToTraits(newContainerTrait)
-	AddToTraits(newPullSecretTrait)
-	AddToTraits(newJolokiaTrait)
-	AddToTraits(newPrometheusTrait)
-	AddToTraits(newJvmTrait)
-	AddToTraits(newRouteTrait)
-	AddToTraits(newIstioTrait)
+	AddToTraits(newCronTrait)
+	AddToTraits(newDependenciesTrait)
+	AddToTraits(newDeployerTrait)
+	AddToTraits(newDeploymentTrait)
+	AddToTraits(newEnvironmentTrait)
+	AddToTraits(newErrorHandlerTrait)
+	AddToTraits(newGarbageCollectorTrait)
+	AddToTraits(newHealthTrait)
 	AddToTraits(newIngressTrait)
-	AddToTraits(newServiceBindingTrait)
+	AddToTraits(newIstioTrait)
+	AddToTraits(newJolokiaTrait)
+	AddToTraits(newJvmTrait)
+	AddToTraits(newKameletsTrait)
+	AddToTraits(newKnativeTrait)
+	AddToTraits(newKnativeServiceTrait)
+	AddToTraits(newLoggingTraitTrait)
+	AddToTraits(newInitTrait)
+	AddToTraits(newOpenAPITrait)
 	AddToTraits(newOwnerTrait)
 	AddToTraits(newPdbTrait)
+	AddToTraits(newPlatformTrait)
+	AddToTraits(newPodTrait)
+	AddToTraits(newPrometheusTrait)
+	AddToTraits(newPullSecretTrait)
+	AddToTraits(newQuarkusTrait)
+	AddToTraits(newRouteTrait)
+	AddToTraits(newServiceTrait)
+	AddToTraits(newServiceBindingTrait)
+	AddToTraits(newTolerationTrait)
+	// ^^ Declaration order is not important, but let's keep them sorted for debugging.
 }
