@@ -25,7 +25,6 @@ import (
 	"sort"
 	"strings"
 
-	"github.com/apache/camel-k/pkg/util/property"
 	user "github.com/mitchellh/go-homedir"
 	"github.com/scylladb/go-set/strset"
 
@@ -36,6 +35,7 @@ import (
 	"github.com/apache/camel-k/pkg/metadata"
 	"github.com/apache/camel-k/pkg/util"
 	"github.com/apache/camel-k/pkg/util/camel"
+	"github.com/apache/camel-k/pkg/util/property"
 )
 
 var exactVersionRegexp = regexp.MustCompile(`^(\d+)\.(\d+)\.([\w-.]+)$`)
@@ -46,8 +46,8 @@ func getIntegrationKit(ctx context.Context, c client.Client, integration *v1.Int
 		return nil, nil
 	}
 	kit := v1.NewIntegrationKit(integration.Status.IntegrationKit.Namespace, integration.Status.IntegrationKit.Name)
-	err := c.Get(ctx, ctrl.ObjectKeyFromObject(&kit), &kit)
-	return &kit, err
+	err := c.Get(ctx, ctrl.ObjectKeyFromObject(kit), kit)
+	return kit, err
 }
 
 func collectConfigurationValues(configurationType string, configurable ...v1.Configurable) []string {
@@ -94,7 +94,7 @@ func collectConfigurations(configurationType string, configurable ...v1.Configur
 
 		for _, entry := range entries {
 			if entry.Type == configurationType {
-				var item = make(map[string]string)
+				item := make(map[string]string)
 				item["value"] = entry.Value
 				item["resourceType"] = entry.ResourceType
 				item["resourceMountPoint"] = entry.ResourceMountPoint
@@ -220,3 +220,32 @@ func AddSourceDependencies(source v1.SourceSpec, catalog *camel.RuntimeCatalog)
 
 	return dependencies
 }
+
+// Bool pointer operations:
+
+// BoolP returns a pointer to a bool value
+func BoolP(b bool) *bool {
+	return &b
+}
+
+// IsTrue checks if the bool pointer is defined and true
+func IsTrue(b *bool) bool {
+	return b != nil && *b
+}
+
+// IsNilOrTrue checks if the bool pointer is nil or true.
+// You can use it if the bool pointer is meant to be true by default.
+func IsNilOrTrue(b *bool) bool {
+	return b == nil || *b
+}
+
+// IsFalse checks if the bool pointer is defined and false
+func IsFalse(b *bool) bool {
+	return b != nil && !*b
+}
+
+// IsNilOrFalse checks if the bool pointer is nil or false.
+// You can use it if the bool pointer is meant to be false by default.
+func IsNilOrFalse(b *bool) bool {
+	return b == nil || !*b
+}
