@@ -48,7 +48,7 @@ func CreateBaseImageDockerFile() error {
 }
 
 // CreateIntegrationImageDockerFile --
-func CreateIntegrationImageDockerFile(integrationRunCmd *exec.Cmd) error {
+func CreateIntegrationImageDockerFile(integrationRunCmd *exec.Cmd, startsFromLocalFolder bool) error {
 	dockerFile := []string{}
 
 	// Start from the base image that contains the maven install: <RegistryName>/<BaseImageName>
@@ -62,6 +62,17 @@ func CreateIntegrationImageDockerFile(integrationRunCmd *exec.Cmd) error {
 	dockerFile = append(dockerFile, COPY(util.DefaultPropertiesDirectoryName, GetContainerPropertiesDir()))
 	dockerFile = append(dockerFile, COPY(util.DefaultDependenciesDirectoryName, GetContainerDependenciesDir()))
 
+	// Copy additional folder structure used for integrations built from a separately built local folder.
+	if startsFromLocalFolder {
+		dockerFile = append(dockerFile, RUNMakeDir(util.ContainerQuarkusDirectoryName))
+		dockerFile = append(dockerFile, RUNMakeDir(util.ContainerLibDirectoryName))
+		dockerFile = append(dockerFile, RUNMakeDir(util.ContainerAppDirectoryName))
+
+		dockerFile = append(dockerFile, COPY(util.CustomQuarkusDirectoryName, util.ContainerQuarkusDirectoryName))
+		dockerFile = append(dockerFile, COPY(util.CustomLibDirectoryName, util.ContainerLibDirectoryName))
+		dockerFile = append(dockerFile, COPY(util.CustomAppDirectoryName, util.ContainerAppDirectoryName))
+	}
+
 	// All Env variables the command requires need to be set in the container.
 	for _, keyValue := range integrationRunCmd.Env {
 		values := strings.Split(keyValue, "=")
@@ -101,10 +112,10 @@ func BuildIntegrationImageArgs(imagePath string) []string {
 }
 
 // RunIntegrationImageArgs --
-func RunIntegrationImageArgs(imagePath string) []string {
+func RunIntegrationImageArgs(imagePath string) ([]string, error) {
 	// Construct the docker command:
 	//
-	// docker run --network="host" <dockerRegistry>/<ImageName>
+	// docker run --network=<network-name> --env LAZY_ENV_VAR=value <dockerRegistry>/<ImageName>
 	//
 	return RunImageArgs(imagePath, latestTag)
 }
@@ -132,7 +143,6 @@ func GetContainerRoutesDir() string {
 // ContainerizeFilePaths -- make paths valid container paths given a valid container directory in newDir.
 func ContainerizeFilePaths(currentFilePaths []string, newDir string) []string {
 	newFilePaths := []string{}
-
 	for _, currentFilePath := range currentFilePaths {
 		newFilePaths = append(newFilePaths, newDir+containerFileSeparator+path.Base(currentFilePath))
 	}
@@ -140,20 +150,33 @@ func ContainerizeFilePaths(currentFilePaths []string, newDir string) []string {
 	return newFilePaths
 }
 
+// ContainerizeDependencyPaths -- make dependency paths valid given a valid container directory in newDir
+func ContainerizeDependencyPaths(dependencyPaths []string, newDir string) []string {
+	newDependencyPaths := []string{}
+	for _, currentDependencyPath := range dependencyPaths {
+		newDependencyPath := util.SubstringFrom(currentDependencyPath, util.QuarkusDependenciesBaseDirectory)
+		if newDependencyPath != "" {
+			newDependencyPaths = append(newDependencyPaths, newDir+newDependencyPath)
+		} else {
+			newDependencyPaths = append(newDependencyPaths, newDir+containerFileSeparator+path.Base(currentDependencyPath))
+		}
+	}
+	return newDependencyPaths
+}
+
 // ExtractRegistryName -- Extract registry name from image path.
 func ExtractRegistryName(image string) (string, error) {
 	pathComponents := strings.Split(image, containerFileSeparator)
 
 	// There must be at least two components in the path:
 	//  - docker.io/registry/imageName
-	//  - registry/imageName
+	//  - localhost:5000/<dir>/imageName
+	//  - localhost:5000/<dir>/.../<dir>/imageName
+	//  - localhost:5000/imageName
 	if len(pathComponents) < 2 {
-		return "", errors.New("image path is too short, usage: docker.io/registry/imageName or registry/imageName")
+		return "", errors.New("image path is too short, usage: registry/imageName or registry/*/imageName")
 	}
 
-	// Check if path starts with docker.io if not, add it.
-	if pathComponents[0] == "docker.io" {
-		return strings.Join(pathComponents[0:2], containerFileSeparator), nil
-	}
-	return "docker.io" + containerFileSeparator + pathComponents[1], nil
+	// Registry name is given by the path to the image.
+	return strings.Join(pathComponents[0:len(pathComponents)-1], containerFileSeparator), nil
 }
