@@ -19,40 +19,32 @@ package kubernetes
 
 import (
 	"context"
+	"fmt"
 
-	"github.com/apache/camel-k/pkg/client"
-	routev1 "github.com/openshift/api/route/v1"
 	"github.com/pkg/errors"
+
 	corev1 "k8s.io/api/core/v1"
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
-	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
+
+	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
+
 	serving "knative.dev/serving/pkg/apis/serving/v1"
-	k8sclient "sigs.k8s.io/controller-runtime/pkg/client"
+
+	routev1 "github.com/openshift/api/route/v1"
+
+	"github.com/apache/camel-k/pkg/client"
 )
 
-// ReplaceResources allows to completely replace a list of resources on Kubernetes, taking care of immutable fields and resource versions
-func ReplaceResources(ctx context.Context, c client.Client, objects []runtime.Object) error {
-	for _, object := range objects {
-		err := ReplaceResource(ctx, c, object)
-		if err != nil {
-			return err
-		}
-	}
-	return nil
-}
-
 // ReplaceResource allows to completely replace a resource on Kubernetes, taking care of immutable fields and resource versions
-func ReplaceResource(ctx context.Context, c client.Client, res runtime.Object) error {
+func ReplaceResource(ctx context.Context, c client.Client, res ctrl.Object) error {
 	err := c.Create(ctx, res)
 	if err != nil && k8serrors.IsAlreadyExists(err) {
-		existing := res.DeepCopyObject()
-		var key k8sclient.ObjectKey
-		key, err = k8sclient.ObjectKeyFromObject(existing)
-		if err != nil {
-			return err
+		existing, ok := res.DeepCopyObject().(ctrl.Object)
+		if !ok {
+			return fmt.Errorf("type assertion failed: %v", res.DeepCopyObject())
 		}
-		err = c.Get(ctx, key, existing)
+		err = c.Get(ctx, ctrl.ObjectKeyFromObject(existing), existing)
 		if err != nil {
 			return err
 		}
@@ -69,12 +61,8 @@ func ReplaceResource(ctx context.Context, c client.Client, res runtime.Object) e
 	return nil
 }
 
-func mapRequiredMeta(from runtime.Object, to runtime.Object) {
-	if fromC, ok := from.(metav1.Object); ok {
-		if toC, ok := to.(metav1.Object); ok {
-			toC.SetResourceVersion(fromC.GetResourceVersion())
-		}
-	}
+func mapRequiredMeta(from ctrl.Object, to ctrl.Object) {
+	to.SetResourceVersion(from.GetResourceVersion())
 }
 
 func mapRequiredServiceData(from runtime.Object, to runtime.Object) {
@@ -125,16 +113,9 @@ func mapRequiredKnativeServiceV1Data(from runtime.Object, to runtime.Object) {
 	}
 }
 
-func findResourceDetails(res runtime.Object) string {
+func findResourceDetails(res ctrl.Object) string {
 	if res == nil {
 		return "nil resource"
 	}
-	if meta, ok := res.(metav1.Object); ok {
-		name := meta.GetName()
-		if ty, ok := res.(metav1.Type); ok {
-			return ty.GetKind() + " " + name
-		}
-		return "resource " + name
-	}
-	return "unnamed resource"
+	return res.GetObjectKind().GroupVersionKind().String() + " " + res.GetName()
 }
