@@ -38,3 +38,20 @@ func ToYAML(value runtime.Object) ([]byte, error) {
 
 	return util.JSONToYAML(data)
 }
+
+// ToYAMLNoManagedFields marshal to yaml format but without metadata.managedFields
+func ToYAMLNoManagedFields(value runtime.Object) ([]byte, error) {
+	jsondata, err := ToJSON(value)
+	if err != nil {
+		return nil, err
+	}
+
+	mapdata, err := util.JSONToMap(jsondata)
+	if err != nil {
+		return nil, err
+	}
+
+	delete(mapdata["metadata"].(map[string]interface{}), "managedFields")
+
+	return util.MapToYAML(mapdata)
+}
