@@ -60,8 +60,7 @@ func (p Project) MarshalBytes() ([]byte, error) {
 	e := xml.NewEncoder(w)
 	e.Indent("", "  ")
 
-	err := e.Encode(p)
-	if err != nil {
+	if err := e.Encode(p); err != nil {
 		return []byte{}, err
 	}
 
@@ -109,12 +108,12 @@ func (p *Project) AddDependencies(deps ...Dependency) {
 	}
 }
 
-// AddDependencyGAV a dependency to maven's dependencies
+// AddDependencyGAV adds a dependency to maven's dependencies
 func (p *Project) AddDependencyGAV(groupID string, artifactID string, version string) {
 	p.AddDependency(NewDependency(groupID, artifactID, version))
 }
 
-// AddEncodedDependencyGAV a dependency to maven's dependencies
+// AddEncodedDependencyGAV adds a dependency in GAV format to maven's dependencies
 func (p *Project) AddEncodedDependencyGAV(gav string) {
 	if d, err := ParseGAV(gav); err == nil {
 		// TODO: error handling
@@ -145,6 +144,13 @@ func (p *Project) AddDependencyExclusions(dep Dependency, exclusions ...Exclusio
 	}
 }
 
+func (p *Project) AddEncodedDependencyExclusion(gav string, exclusion Exclusion) {
+	if d, err := ParseGAV(gav); err == nil {
+		// TODO: error handling
+		p.AddDependencyExclusion(d, exclusion)
+	}
+}
+
 type propertiesEntry struct {
 	XMLName xml.Name
 	Value   string `xml:",chardata"`
