@@ -18,6 +18,7 @@ limitations under the License.
 package test
 
 import (
+	"context"
 	"strings"
 
 	"github.com/apache/camel-k/pkg/apis"
@@ -48,7 +49,7 @@ func NewFakeClient(initObjs ...runtime.Object) (client.Client, error) {
 		return nil, err
 	}
 
-	c := fake.NewFakeClientWithScheme(scheme, initObjs...)
+	c := fake.NewClientBuilder().WithScheme(scheme).WithRuntimeObjects(initObjs...).Build()
 
 	camelClientset := fakecamelclientset.NewSimpleClientset(filterObjects(scheme, initObjs, func(gvk schema.GroupVersionKind) bool {
 		return strings.Contains(gvk.Group, "camel")
@@ -105,6 +106,11 @@ func (c *FakeClient) GetCurrentNamespace(kubeConfig string) (string, error) {
 	return "", nil
 }
 
+// Patch mimicks patch for server-side apply and simply creates the obj
+func (c *FakeClient) Patch(ctx context.Context, obj controller.Object, patch controller.Patch, opts ...controller.PatchOption) error {
+	return c.Create(ctx, obj)
+}
+
 func (c *FakeClient) Discovery() discovery.DiscoveryInterface {
 	return &FakeDiscovery{
 		DiscoveryInterface: c.Interface.Discovery(),
